/*
 * Project name:
     IRint.vtft
 * Generated by:
     Visual TFT
 * Date of creation
     21/05/2016
 * Time of creation
     20:50:30
 * Test configuration:
     MCU:             STM32F407ZG
     Dev.Board:       Mikromedia_7_for_STM32F4_ARM
                      http://www.mikroe.com/mikromedia/7/stm32f4/
     Oscillator:      150000000 Hz
     SW:              mikroC PRO for ARM
                      http://www.mikroe.com/mikroc/arm/
 */

#include "IRint_objects.h"

// test program for mikromedia plus 7 with STM32F407ZG (hardware revision 1.02)
// decodes NEC IR protocol using on-board IR receiver of mikromedia7 for STM32F4
//     PB10 is external interrupt pin driven by IR receiver
//     Program toggles Blue LED on IR reception
//     MCU:             STM32F407ZG
//     dev.board:       STM32MMBplus7
//     Oscillator:      HSI-PLL, 150.000MHz

// Author accepts no responsibility for anything - use this code at your own risk
// amateur code just for fun
// scope signals available if you want them, but if not, just ignore
// don't understand why timer 2 calculations seem to work for 75MHz clock. Maybe clock is not really 150MHz??
// only one message can be received - mutiple messages will be ignored until a long gap is found between messages
// very limited error checking and very crude decoding techniques used

// Extended NEC protocol: 1/4 or 1/3 duty cycle 38khz (21 pulses per bit approx)
// 9ms mark then 4.5ms space        header
// 560us mark, 560us space          zero
// 560us mark, 1.69ms space         one
// 4 bytes, LSB first
// 560us mark - long space                stop bit of one
// option 1 = repeat every 110ms (if wanted), but just 9ms mark, 2.25 space, 560us mark (no data)
// option 2 = repeat full message
// 00ff = default address, custom codes available, byte 4 is inverse of byte 3
// byte1 is low byte of address, byte2 is either inverse of byte 1 or high byte of address


// global variables
unsigned long input_data;                        // accumulate bits here
unsigned long mydebug;                           // for debug only
unsigned int counter;                            // store Timer 2 count in uS
unsigned int ir_add;                             // 16 bit address
unsigned int ir_cmd;                             // 8 bit command and 8 bit inverted command
unsigned char gap_flag;                          // set if no IR signals for a while - indicates inter-message gap
unsigned char repeat_count;                      // count of repeat messages
unsigned char repeat_flag;                       // show that repeat message display update is required
unsigned char ir_state;                          // 0=waiting for gap, 1=gap found,   rest tba
unsigned char bit_count;                         // count IR bits in
unsigned char ir_found;                          // set when IR message sucessfully received
unsigned char ir_now;                            // shows input level just now 0=space(high) 1=mark(low)
unsigned char cmp1;
unsigned char cmp2;
char text_buffer[20];                            // general purpose buffer

// Timer2 interrupt every 25 mS and count every 1 uS
// Counter TIM2_CNT counts up from 0 to TIM2_ARR value before interrupting and resetting to 0
void InitTimer2(){
  RCC_APB1ENR.TIM2EN = 1;
  TIM2_CR1.CEN = 0;                              // counter disable while configuring
  TIM2_PSC = 75;                                 // prescaler;  75,000,000 Hz / 75 = 1000000 Hz (1uS)    Clock seems to be half that expected !!!!!
  TIM2_ARR = 25000;                              // auto-reload register;  1000000 Hz / 25000 = 40 Hz (25mS)
  NVIC_IntEnable(IVT_INT_TIM2);
  TIM2_DIER.UIE = 1;                             // enable T2 interrupt
  TIM2_CR1.CEN = 1;                              // counter enable now ready
}

// timer 2 interrupt every 25 mS
void Timer2_interrupt() iv IVT_INT_TIM2 {
  TIM2_SR.UIF = 0;                               // clear interrupt flag
  GPIOF_ODR.B2 = 1;                              // F2 pin 22 set to indicate on scope that inter-message gap found (Gnd on 2 and 26)
  gap_flag = 1;                                  // indicate gap found
  GPIOC_ODR.B13 = 1;                             // scope test only - pin 8 C13 - clear good header indicator
  GPIOE_ODR.B4 = 0;                              // scope test only - pin 9 E4 - clear good message found indicator
  GPIOF_ODR.B1 = 0;                              // scope test only - pin 43 PF1 - clear repeat found indication
  if(ir_state == 0){
    ir_state = 1;                                // gap found - indicate in IR state indicator
  }
}

// interrupt routine for PB10 rising or falling edge of IR receiver input
void ExtInt() iv IVT_INT_EXTI15_10 ics ICS_AUTO {
  EXTI_PR.B10 = 1;                               // clear PB10 interrupt flag
  gap_flag = 0;                                  // reset gap flag
  GPIOF_ODR.B2 = 0;                              // scope debug info pin 22 - no gap yet
  if(EXTI_RTSR.B10){                             // if rising edge
    GPIOB_ODR.B4 = 0;                            // Blue LED off to indicate space
    GPIOF_ODR.B7 = 1;                            // F7 pin 21 high to indicate space on scope (Gnd on 2 and 26)
    EXTI_RTSR = 0x00000000;                      // No interrupt on Rising edge
    EXTI_FTSR = 0x00000400;                      // Set Interrupt on Falling edge (PB10)
    ir_now = 1;                                  // show current IR input level is a space (high)
  }
  else{                                          // falling edge found
    GPIOB_ODR.B4 = 1;                            // Blue LED on to indicate mark
    GPIOF_ODR.B7 = 0;                            // F7 pin 21 low to indicate mark on scope (Gnd on 2 and 26)
    EXTI_RTSR = 0x00000400;                      // Set interrupt on Rising edge
    EXTI_FTSR = 0x00000000;                      // No Interrupt on Falling edge (PB10)
    ir_now = 0;                                  // show current IR input level is a mark (low)
  }
  
  switch(ir_state){
    case 1:                                             //Idle,starting
      ir_state = 2;
      break;
    case 2:                                             // start_bit, found rising edge, check length for 9ms
      counter = TIM2_CNT;                               //
      if((counter > 8000) && (counter < 10000)){        // acceptable uS values for start
          ir_state = 3;                                 // start receiving bits
      }
      else{                                             // fault signal, reset to idle
          ir_state = 0;
      }
      break;
    case 3:
      if(!ir_now){                                         // only interested in space timing - i.e. just returned to mark
          counter = TIM2_CNT;                              //
          if((counter > 2000) && (counter < 2500)){        // acceptable uS values for repeat space time of 2.25mS
              bit_count = 0;                               // start counting bits in
              input_data = 0;                              // clear old value
              GPIOF_ODR.B1 = 1;                            // scope test only - pin 43 PF1 - repeat
              repeat_count++;                                     // count the number of repeat messages since last full message
              repeat_flag = 1;                                    // signal that display update is needed
              ir_state = 0;                                       // ready to start receiving again
          }
          if((counter > 4000) && (counter < 5000)){        // acceptable uS values for start space time
              bit_count = 0;                               // start counting bits in
              input_data = 0;                              // clear old value
              ir_state = 4;                                // start receiving bits
          }
          else{                                            // fault signal, reset to idle
              ir_state = 0;
          }
          break;
      }
    case 4:   //capture bit, start receiving data
      if(!ir_now){                                        // only interested in space timing - i.e. just returned to mark
        // check pulse length for "0" (560uS mark + 560uS space)
        // or "1" (560uS mark + 1.69 mS space)
        counter = TIM2_CNT;                               //  get mark time in uS
        bit_count++;
        input_data >>= 1;                                 // make room for 0 bit

        if(counter > 1200){                               // acceptable uS value for zero/one discrimination
            input_data |= 0x80000000UL;                   // change 0 to 1
        }
        if (bit_count == 32){                             // complete 32 bits
            GPIOE_ODR.B4 = 1;                             // scope test only - pin 9 E4
            mydebug = input_data;                                // debug only
            ir_found = 1;                                 // indicate that a message is ready
            ir_add = input_data;                          // pick out the 16 address bits
            ir_cmd = (input_data >> 16);                  // pick out the 16 command bits  (8 bits data and 8 bits inverted data)

            ir_state = 0;                                 // ready to start receiving again
        }
      }
      break;
    default: ir_state = 0;                                // do not expect to get here, but if I do then reset IR receive
  }

  TIM2_CNT = 0;                                  // reset gap counter

}

void main() {
  GPIO_Digital_Output(&GPIOB_BASE, _GPIO_PINMASK_4);              // Enable digital output on PORTB4 Blue LED
  GPIOB_ODR.B4 = 0;                                               // blue LED off to start with
  GPIO_Digital_Input(&GPIOB_BASE, _GPIO_PINMASK_10);              // IR input on PB10
  GPIO_Digital_Output(&GPIOE_BASE, _GPIO_PINMASK_4);              // Enable digital output on PORTE4 for scope tests - pin 9 of MMB7 (Gnd = 2 and 26)
  GPIOE_ODR.B4 = 0;                                               // PE4 off to start with
  GPIO_Digital_Output(&GPIOF_BASE, _GPIO_PINMASK_2);              // Enable digital output on PORTF2 for scope tests - pin 22 of MMB7 (Gnd = 2 and 26)
  GPIOF_ODR.B2 = 0;                                               // PF2 off to start with
  GPIO_Digital_Output(&GPIOF_BASE, _GPIO_PINMASK_7);              // Enable digital output on PORTF7 for scope tests - pin 21 of MMB7 (Gnd = 2 and 26)
  GPIOF_ODR.B7 = 0;                                               // PF7 off to start with
  GPIO_Digital_Output(&GPIOF_BASE, _GPIO_PINMASK_1);              // Enable digital output on PORTF1 for scope tests - pin 43 of MMB7 (Gnd = 2 and 26)
  GPIOF_ODR.B1 = 0;                                               // PF1 off to start with

  SYSCFGEN_bit = 1;                    // Enable clock for alternate pin functions
  SYSCFG_EXTICR3 = 0x00000100;         // Map external interrupt on PB10
  EXTI_RTSR = 0x00000000;              // No interrupt on Rising edge
  EXTI_FTSR = 0x00000400;              // Set Interrupt on Falling edge (PB10)
  EXTI_IMR |= 0x00000400;              // Set mask
  NVIC_IntEnable(IVT_INT_EXTI15_10);   // Enable External interrupt
  InitTimer2();                        // timer 2 interrupts every 100mS
  gap_flag = 0;                        // assume no gap yet
  ir_state = 0;                        // waiting for gap
  repeat_flag = 0;                     // no repeat messages yet

  Start_TP();

  while (1) {
    Check_TP();
    if(ir_found){                                           // has an IR message been decoded?
      ir_found=0;                                           // prevent second processing of message
      repeat_count = 0;                                     // clear count of repeat messages
      WordToHex(ir_add, text_buffer);                       // update display information ......
      ButtonAddress.Caption[2] = text_buffer[2];
      ButtonAddress.Caption[3] = text_buffer[3];
      ButtonAddress.Caption[4] = text_buffer[0];
      ButtonAddress.Caption[5] = text_buffer[1];
      WordToHex(ir_cmd, text_buffer);
      ButtonInverse.Caption[2] = text_buffer[0];
      ButtonInverse.Caption[3] = text_buffer[1];
      ButtonCommand.Caption[2] = text_buffer[2];
      ButtonCommand.Caption[3] = text_buffer[3];
      LongWordToHex(mydebug, text_buffer);
      ButtonDebug.Caption[0] = text_buffer[0];
      ButtonDebug.Caption[1] = text_buffer[1];
      ButtonDebug.Caption[2] = text_buffer[2];
      ButtonDebug.Caption[3] = text_buffer[3];
      ButtonDebug.Caption[4] = text_buffer[4];
      ButtonDebug.Caption[5] = text_buffer[5];
      ButtonDebug.Caption[6] = text_buffer[6];
      ButtonDebug.Caption[7] = text_buffer[7];
      ButtonInverse.Gradient_Start_Color = 0xf800;                // set red to start with
      cmp1 = ir_cmd >> 8;
      cmp2 = ir_cmd;
      if(cmp1 == ~cmp2){                                          // check that command is inverse of inverse command
          ButtonInverse.Gradient_Start_Color = 0x4d81;            // change to green if match is OK
      }
      LabelExt.Font_Color = Label8.Font_Color;                    // make "(extended)" text visible to start with
      cmp1 = ir_add >> 8;
      cmp2 = ir_add;
      if(cmp1 == ~cmp2){                                          // check that command is inverse of inverse command
          LabelExt.Font_Color = 0;                                // make extended text invisible if match is OK
      }
      WordToHex(repeat_count, text_buffer);
      ButtonRepeats.Caption[2] = text_buffer[2];
      ButtonRepeats.Caption[3] = text_buffer[3];
      DrawButton(&ButtonDebug);
      DrawButton(&ButtonAddress);
      DrawButton(&ButtonCommand);
      DrawButton(&ButtonInverse);
      DrawButton(&ButtonRepeats);
      DrawLabel(&LabelExt);
    }
    if(repeat_flag){                                              // has an IR repeat message been found?
      repeat_flag = 0;                                            // prevent pointless Screen updates
      WordToHex(repeat_count, text_buffer);
      ButtonRepeats.Caption[2] = text_buffer[2];
      ButtonRepeats.Caption[3] = text_buffer[3];
      DrawButton(&ButtonRepeats);
    }
  }
}