//  NOTE...  Project not yet working - still under development

/*
 * Project name:
     IRint.vtft
 * Generated by:
     Visual TFT
 * Date of creation
     218/10/2016
 * Time of creation
     20:50:30
 * Test configuration:
     MCU:             STM32F407ZG
     Dev.Board:       Mikromedia_7_for_STM32F4_ARM
                      http://www.mikroe.com/mikromedia/7/stm32f4/
     Oscillator:      150000000 Hz
     SW:              mikroC PRO for ARM
                      http://www.mikroe.com/mikroc/arm/
 */

#include "IRint_objects.h"

// test program for mikromedia plus 7 with STM32F407ZG (hardware revision 1.02)
// decodes RC5 IR protocol using on-board IR receiver of mikromedia7 for STM32F4
//     PB10 is external interrupt pin driven by IR receiver
//     Program toggles Blue LED on IR reception
//     MCU:             STM32F407ZG
//     dev.board:       STM32MMBplus7
//     Oscillator:      HSI-PLL, 150.000MHz

// Author accepts no responsibility for anything - use this code at your own risk
// amateur code just for fun
// scope signals available if you want them, but if not, just ignore
// very limited error checking and very crude decoding techniques used

// RC5 protocol:
// 24.889ms whole command
// 0=0.889ms mark, 0.889ms space                1=0.889ms space, 0.889ms mark
// start bit = 1         (only second half of bit (mark) is detectable as space is lost in no data period
// start bit = 1        (i.e. two start bits) or field bit in extended mode, where 0 denotes commands 64 to 127 decimal
// toggle          = x        alternates between key presses to distinguish continued press
// 5 address bits
// 6 command bits


// global variables
unsigned char gap_flag;                          // set if no IR signals for a while - indicates inter-message gap
unsigned char ir_state;                          // 0=waiting for gap, 1=gap found,   rest tba
unsigned int counter;                            // store Timer 2 count in uS
unsigned char bit_count;                         // count IR bits in
unsigned int input_data;                         // accumulate bits here
unsigned char ir_found;                          // set when IR message sucessfully received
unsigned char ir_now;                            // shows input level just now 0=space(high) 1=mark(low)
unsigned int ir_add;                             // 5 bit address
unsigned int ir_cmd;                             // 6 bit command
unsigned int mydebug;                            // for debug only
char text_buffer[20];                            // general purpose buffer

// Timer2 interrupt every 50 mS and count every 1 uS
// Counter TIM2_CNT counts up from 0 to TIM2_ARR value before interrupting and resetting to 0
void InitTimer2(){
  RCC_APB1ENR.TIM2EN = 1;
  TIM2_CR1.CEN = 0;                              // counter disable while configuring
  TIM2_PSC = 75;                                 // prescaler;  75,000,000 Hz / 75 = 1000000 Hz (1uS)    Clock seems to be half that expected !!!!!
  TIM2_ARR = 50000;                              // auto-reload register;  1000000 Hz / 50000 = 20 Hz (50mS)
  NVIC_IntEnable(IVT_INT_TIM2);
  TIM2_DIER.UIE = 1;                             // enable T2 interrupt
  TIM2_CR1.CEN = 1;                              // counter enable now ready
}

// timer 2 interrupt every 50 mS
void Timer2_interrupt() iv IVT_INT_TIM2 {
  TIM2_SR.UIF = 0;                               // clear interrupt flag
  GPIOF_ODR.B2 = 1;                              // F2 pin 22 set to indicate on scope that inter-message gap found (Gnd on 2 and 26)
  gap_flag = 1;                                  // indicate gap found
  if(ir_state == 0){
    ir_state = 1;                                // gap found - indicate in IR state indicator
      GPIOE_ODR.B4 = 0;                          // scope test only - pin 9 E4
  }
}

// interrupt routine for PB10 rising or falling edge of IR receiver input
void ExtInt() iv IVT_INT_EXTI15_10 ics ICS_AUTO {
  EXTI_PR.B10 = 1;                               // clear PB10 interrupt flag
  gap_flag = 0;                                  // reset gap flag
  GPIOF_ODR.B2 = 0;                              // scope debug info pin 22 - no gap yet
  if(EXTI_RTSR.B10){                             // if rising edge
    GPIOB_ODR.B4 = 0;                            // Blue LED off to indicate space
    GPIOF_ODR.B7 = 1;                            // F7 pin 21 high to indicate space on scope (Gnd on 2 and 26)
    EXTI_RTSR = 0x00000000;                      // No interrupt on Rising edge
    EXTI_FTSR = 0x00000400;                      // Set Interrupt on Falling edge (PB10)
    ir_now = 1;                                  // show current IR input level is a space (high)
  }
  else{                                          // falling edge found
    GPIOB_ODR.B4 = 1;                            // Blue LED on to indicate mark
    GPIOF_ODR.B7 = 0;                            // F7 pin 21 low to indicate mark on scope (Gnd on 2 and 26)
    EXTI_RTSR = 0x00000400;                      // Set interrupt on Rising edge
    EXTI_FTSR = 0x00000000;                      // No Interrupt on Falling edge (PB10)
    ir_now = 0;                                  // show current IR input level is a mark (low)
  }
  
  switch(ir_state){
    case 1:   //Idle,starting
      ir_state = 2;
      break;
    case 2:   // start_bit, found rising edge, check length for 0.9ms or 1.8ms
      counter = TIM2_CNT;                        //
      mydebug = counter;                         // debug only
      ir_state = 0;                              // default to fail state
      if((counter > 800) && (counter < 1000)){   // acceptable uS values for start bits of 1 1
          bit_count = 0;                         // start counting bits in
          input_data = 0;                        // clear old value
          ir_state = 3;                          // start receiving bits
      }
      if((counter > 1600) && (counter < 2000)){  // acceptable uS values for start bits of 1 0
          bit_count = 0;                         // start counting bits in
          input_data = 0;                        // clear old value
          ir_state = 3;                          // start receiving bits
      }
      break;
    case 3:   //capture bit, start receiving data
      if(ir_now){                                // only interested in mark timing - i.e. just returned to space
        //check pulse length for "0" (0.6 mS space + 0.6 mS mark)
        // or "1" (0.6 mS space + 1.2 mS mark)
        counter = TIM2_CNT;                       //  get mark time in uS
        bit_count++;
        input_data >>= 1;                         // make room for 0 bit

        if(counter > 900){                        // acceptable uS value for zero/one discrimination
            input_data |= 0x8000;                 // change 0 to 1
        }
        if (bit_count == 12){                     // complete 12 bits (toggle, 5 address, 6 command)
            ir_found = 1;                         // indicate that a message is ready
            input_data >>= 4;                     // shift 12 bits into lower bits of word
            ir_add = (input_data >> 6) & 0x1F;    // pick out the 5 address bits
            ir_cmd = input_data & 0x3F;           // pick out the 6 command bits

            ir_state = 0;                         // ready to start receiving again
            GPIOE_ODR.B4 = 1;                     // scope test only - pin 9 E4
        }
      }
      break;
    default: ir_state = 0;
  }

  TIM2_CNT = 0;                                  // reset gap counter

}

void main() {
  GPIO_Digital_Output(&GPIOB_BASE, _GPIO_PINMASK_4);              // Enable digital output on PORTB4 Blue LED
  GPIOB_ODR.B4 = 0;                                               // blue LED off to start with
  GPIO_Digital_Input(&GPIOB_BASE, _GPIO_PINMASK_10);              // IR input on PB10
  GPIO_Digital_Output(&GPIOE_BASE, _GPIO_PINMASK_4);              // Enable digital output on PORTE4 for scope tests - pin 9 of MMB7 (Gnd = 2 and 26)
  GPIOE_ODR.B4 = 0;                                               // PE4 off to start with
  GPIO_Digital_Output(&GPIOF_BASE, _GPIO_PINMASK_2);              // Enable digital output on PORTF2 for scope tests - pin 22 of MMB7 (Gnd = 2 and 26)
  GPIOF_ODR.B2 = 0;                                               // PF2 off to start with
  GPIO_Digital_Output(&GPIOF_BASE, _GPIO_PINMASK_7);              // Enable digital output on PORTF7 for scope tests - pin 21 of MMB7 (Gnd = 2 and 26)
  GPIOF_ODR.B7 = 0;                                               // PF7 off to start with

  SYSCFGEN_bit = 1;                    // Enable clock for alternate pin functions
  SYSCFG_EXTICR3 = 0x00000100;         // Map external interrupt on PB10
  EXTI_RTSR = 0x00000000;              // No interrupt on Rising edge
  EXTI_FTSR = 0x00000400;              // Set Interrupt on Falling edge (PB10)
  EXTI_IMR |= 0x00000400;              // Set mask
  NVIC_IntEnable(IVT_INT_EXTI15_10);   // Enable External interrupt
  InitTimer2();                        // timer 2 interrupts every 100mS
  gap_flag = 0;                        // assume no gap yet
  ir_state = 0;                        // waiting for gap

  Start_TP();

  while (1) {
    Check_TP();
    if(ir_found){                                           // has an IR message been decoded?
      ir_found=0;                                           // prevent second processing of message
      WordToHex(ir_add, text_buffer);
      ButtonAddress.Caption[2] = text_buffer[2];
      ButtonAddress.Caption[3] = text_buffer[3];
      WordToHex(ir_cmd, text_buffer);
      ButtonCommand.Caption[2] = text_buffer[2];
      ButtonCommand.Caption[3] = text_buffer[3];
      DrawButton(&ButtonAddress);
      DrawButton(&ButtonCommand);
    }
  }
}
