#include "pintest_objects.h"
#include "pintest_resources.h"
#include "built_in.h"


// TFT module connections
unsigned int TFT_DataPort at GPIOE_ODR;
sbit TFT_RST at GPIOF_ODR.B14;
sbit TFT_RS at GPIOF_ODR.B15;
sbit TFT_CS at GPIOF_ODR.B13;
sbit TFT_RD at GPIOF_ODR.B12;
sbit TFT_WR at GPIOF_ODR.B11;
sbit TFT_BLED at GPIOF_ODR.B10;
// End TFT module connections


// Global variables
unsigned int Xcoord, Ycoord;
char PenDown;
void *PressedObject;
int PressedObjectType;
unsigned int caption_length, caption_height;
unsigned int display_width, display_height;

int _object_count;
unsigned short object_pressed;
TLabel *local_label;
TLabel *exec_label;
int label_order;


void Write_to_Data_Lines(unsigned char _hi, unsigned char _lo) {
  unsigned int temp;
  temp = GPIOE_ODR;
  temp &= 0x00FF;
  GPIOE_ODR = temp | (_hi << 8);
  temp = GPIOG_ODR;
  temp &= 0xFF00;
  GPIOG_ODR = temp | _lo;
}

void Set_Index(unsigned short index) {
  TFT_RS = 0;
  Write_to_Data_Lines(0, index);
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

void Write_Command(unsigned short cmd) {
  TFT_RS = 1;
  Write_to_Data_Lines(0, cmd);
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

void Write_Data(unsigned int _data) {
  TFT_RS = 1;
  Write_to_Data_Lines(Hi(_data), Lo(_data));
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

static void InitializeTouchPanel() {
  TFT_Set_Active(Set_Index, Write_Command, Write_Data);
  TFT_Init_SSD1963_7Inch_800x480(480, 800);

  TFT_Set_DBC_SSD1963(255);

  PenDown = 0;
  PressedObject = 0;
  PressedObjectType = -1;
}


/////////////////////////
  TScreen*  CurrentScreen;

  TScreen                Screen1;
  TLabel                 Label1;
char Label1_Caption[27] = "Pin diagram for STM32 MMB7";

  TLabel                 Label3;
char Label3_Caption[11] = "GPIO F2 22";

  TLabel                 Label4;
char Label4_Caption[11] = "GPIO F7 21";

  TLabel                 Label5;
char Label5_Caption[7] = "Gnd 26";

  TLabel                 Label6;
char Label6_Caption[6] = "Gnd 2";

  TLabel                 Label7;
char Label7_Caption[10] = "GPIO E4 9";

  TLabel                 Label2;
char Label2_Caption[9] = "5V pwr 1";

  TLabel                 Label8;
char Label8_Caption[6] = "nc 23";

  TLabel                 Label9;
char Label9_Caption[6] = "nc 24";

  TLabel                 Label10;
char Label10_Caption[7] = "3V3 25";

  TLabel                 Label11;
char Label11_Caption[11] = "SPI1 B5 20";

  TLabel                 Label12;
char Label12_Caption[11] = "SPI1 A6 19";

  TLabel                 Label13;
char Label13_Caption[11] = "SPI1 A5 18";

  TLabel                 Label14;
char Label14_Caption[12] = "SPI1 A15 17";

  TLabel                 Label15;
char Label15_Caption[11] = "GPIO D1 16";

  TLabel                 Label16;
char Label16_Caption[11] = "GPIO D0 15";

  TLabel                 Label17;
char Label17_Caption[12] = "SPI2 B14 14";

  TLabel                 Label18;
char Label18_Caption[12] = "SPI2 B15 13";

  TLabel                 Label19;
char Label19_Caption[12] = "SPI2 B13 12";

  TLabel                 Label20;
char Label20_Caption[12] = "SPI2 B12 11";

  TLabel                 Label21;
char Label21_Caption[12] = "GPIO C13 10";

  TLabel                 Label22;
char Label22_Caption[14] = "Analogue C3 8";

  TLabel                 Label23;
char Label23_Caption[14] = "Analogue C2 7";

  TLabel                 Label24;
char Label24_Caption[14] = "Analogue C0 6";

  TLabel                 Label25;
char Label25_Caption[14] = "Analogue B1 5";

  TLabel                 Label26;
char Label26_Caption[14] = "Analogue B0 4";

  TLabel                 Label27;
char Label27_Caption[14] = "Analogue A4 3";

  TLabel                 Label28;
char Label28_Caption[7] = "27 Rst";

  TLabel                 Label29;
char Label29_Caption[7] = "28 3V3";

  TLabel                 Label30;
char Label30_Caption[15] = "29 Audio Out L";

  TLabel                 Label31;
char Label31_Caption[15] = "30 Audio Out R";

  TLabel                 Label32;
char Label32_Caption[14] = "31 Audio In L";

  TLabel                 Label33;
char Label33_Caption[14] = "32 Audio In R";

  TLabel                 Label34;
char Label34_Caption[11] = "33 D12 PWM";

  TLabel                 Label35;
char Label35_Caption[11] = "34 D13 PWM";

  TLabel                 Label36;
char Label36_Caption[11] = "35 D14 PWM";

  TLabel                 Label37;
char Label37_Caption[11] = "36 D15 PWM";

  TLabel                 Label38;
char Label38_Caption[10] = "37 E5 PWM";

  TLabel                 Label39;
char Label39_Caption[10] = "38 E6 PWM";

  TLabel                 Label40;
char Label40_Caption[10] = "39 E0 INT";

  TLabel                 Label41;
char Label41_Caption[10] = "40 E1 INT";

  TLabel                 Label42;
char Label42_Caption[10] = "41 E2 INT";

  TLabel                 Label43;
char Label43_Caption[10] = "42 F3 INT";

  TLabel                 Label44;
char Label44_Caption[11] = "43 F1 I2C2";

  TLabel                 Label45;
char Label45_Caption[11] = "44 F0 I2C2";

  TLabel                 Label46;
char Label46_Caption[12] = "45 C7 UART6";

  TLabel                 Label47;
char Label47_Caption[12] = "46 C6 UART6";

  TLabel                 Label48;
char Label48_Caption[12] = "47 A3 UART2";

  TLabel                 Label49;
char Label49_Caption[12] = "48 D5 UART2";

  TLabel                 Label50;
char Label50_Caption[11] = "49 B6 I2C1";

  TLabel                 Label51;
char Label51_Caption[11] = "50 B7 I2C1";

  TLabel                 Label52;
char Label52_Caption[7] = "51 Gnd";

  TLabel                 Label53;
char Label53_Caption[19] = "52 VDC 5-12V input";

  TLabel                 Label54;
char Label54_Caption[7] = "- Batt";

  TLabel                 Label55;
char Label55_Caption[7] = "+ Batt";

  TLabel                 Label56;
char Label56_Caption[10] = "LED_R G15";

  TLabel                 Label57;
char Label57_Caption[14] = "LED_G B3 PWM1";

  TLabel                 Label58;
char Label58_Caption[14] = "LED_B B4 PWM2";

  TLabel                 Label59;
char Label59_Caption[7] = "IR B10";

  TLabel                 Label60;
char Label60_Caption[15] = "Light Level F9";

  TLabel                 Label61;
char Label61_Caption[9] = "Temp F10";

  TLabel                 Label62;
char Label62_Caption[20] = "pin SDIO  port  SPI";

  TLabel                 Label63;
char Label63_Caption[16] = "1 DAT2  C10  nc";

  TLabel                 Label64;
char Label64_Caption[19] = "2 DAT3  C11  CS/SS";

  TLabel                 Label65;
char Label65_Caption[22] = "3 CMD    D2   DI/MOSI";

  TLabel                 Label66;
char Label66_Caption[21] = "4 Vcc            Vdd";

  TLabel                 Label67;
char Label67_Caption[18] = "5 CLK    C12  SCK";

  TLabel                 Label68;
char Label68_Caption[20] = "6 Gnd           Gnd";

  TLabel                 Label69;
char Label69_Caption[21] = "7 DAT0   C8  DO/MISO";

  TLabel                 Label70;
char Label70_Caption[22] = "8 DAT1   C9  reserved";

  TLabel                 Label71;
char Label71_Caption[20] = "CS# detect  D3  CS#";

  TLabel                 Label72;
char Label72_Caption[9] = "micro SD";

  TLabel                 Label73;
char Label73_Caption[4] = "3V3";

  TLabel                 Label74;
char Label74_Caption[4] = "Gnd";

  TLabel                 Label75;
char Label75_Caption[6] = "CAN H";

  TLabel                 Label76;
char Label76_Caption[6] = "CAN L";

  TLabel                 Label77;
char Label77_Caption[9] = "Piezo B8";

  TLabel                 Label78;
char Label78_Caption[17] = "pin port  signal";

  TLabel                 Label79;
char Label79_Caption[13] = "1 G12  RF_CE";

  TLabel                 Label80;
char Label80_Caption[15] = "2 G9    RF_CS#";

  TLabel                 Label81;
char Label81_Caption[16] = "3 B13  SPI2_SCK";

  TLabel                 Label82;
char Label82_Caption[17] = "4 B15  SPI2_MOSI";

  TLabel                 Label83;
char Label83_Caption[17] = "5 B14  SPI2_MISO";

  TLabel                 Label84;
char Label84_Caption[15] = "6 G10  RF_INT#";

  TLabel                 Label85;
char Label85_Caption[9] = "nRF24L01";

  TLabel                 Label86;
char Label86_Caption[11] = "CAN Tx PD0";

  TLabel                 Label87;
char Label87_Caption[11] = "CAN Rx PD1";

  TLabel                 Label88;
char Label88_Caption[11] = "WIFI_TX C7";

  TLabel                 Label89;
char Label89_Caption[11] = "WIFI_RX C8";

  TLabel                 Label90;
char Label90_Caption[15] = "WIFI_RESET F10";

  TLabel                 Label91;
char Label91_Caption[20] = "Serial Flash M2SP80";

  TLabel                 Label92;
char Label92_Caption[15] = "Accel ADXL 345";

  TLabel                 Label93;
char Label93_Caption[12] = "I2C1_SCL B6";

  TLabel                 Label94;
char Label94_Caption[12] = "I2C1_SDA B7";

  TLabel                 Label95;
char Label95_Caption[13] = "ACCEL_INT B9";

  TLabel                 Label96;
char Label96_Caption[16] = "1 FLASH_CS# B11";

  TLabel                 Label97;
char Label97_Caption[17] = "2 SPI2_MISO  B14";

  TLabel                 Label98;
char Label98_Caption[18] = "6 SPI2_SCK    B13";

  TLabel                 Label99;
char Label99_Caption[17] = "3 SPI2_MOSI  B15";

  TLabel                 Label100;
char Label100_Caption[12] = "5 to 12V DC";

  TLabel                 * const code Screen1_Labels[100]=
         {
         &Label1,              
         &Label3,              
         &Label4,              
         &Label5,              
         &Label6,              
         &Label7,              
         &Label2,              
         &Label8,              
         &Label9,              
         &Label10,             
         &Label11,             
         &Label12,             
         &Label13,             
         &Label14,             
         &Label15,             
         &Label16,             
         &Label17,             
         &Label18,             
         &Label19,             
         &Label20,             
         &Label21,             
         &Label22,             
         &Label23,             
         &Label24,             
         &Label25,             
         &Label26,             
         &Label27,             
         &Label28,             
         &Label29,             
         &Label30,             
         &Label31,             
         &Label32,             
         &Label33,             
         &Label34,             
         &Label35,             
         &Label36,             
         &Label37,             
         &Label38,             
         &Label39,             
         &Label40,             
         &Label41,             
         &Label42,             
         &Label43,             
         &Label44,             
         &Label45,             
         &Label46,             
         &Label47,             
         &Label48,             
         &Label49,             
         &Label50,             
         &Label51,             
         &Label52,             
         &Label53,             
         &Label54,             
         &Label55,             
         &Label56,             
         &Label57,             
         &Label58,             
         &Label59,             
         &Label60,             
         &Label61,             
         &Label62,             
         &Label63,             
         &Label64,             
         &Label65,             
         &Label66,             
         &Label67,             
         &Label68,             
         &Label69,             
         &Label70,             
         &Label71,             
         &Label72,             
         &Label73,             
         &Label74,             
         &Label75,             
         &Label76,             
         &Label77,             
         &Label78,             
         &Label79,             
         &Label80,             
         &Label81,             
         &Label82,             
         &Label83,             
         &Label84,             
         &Label85,             
         &Label86,             
         &Label87,             
         &Label88,             
         &Label89,             
         &Label90,             
         &Label91,             
         &Label92,             
         &Label93,             
         &Label94,             
         &Label95,             
         &Label96,             
         &Label97,             
         &Label98,             
         &Label99,             
         &Label100             
         };



static void InitializeObjects() {
  Screen1.Color                     = 0x0000;
  Screen1.Width                     = 480;
  Screen1.Height                    = 800;
  Screen1.LabelsCount               = 100;
  Screen1.Labels                    = Screen1_Labels;
  Screen1.ObjectsCount              = 100;


  Label1.OwnerScreen     = &Screen1;
  Label1.Order           = 0;
  Label1.Left            = 42;
  Label1.Top             = 91;
  Label1.Width           = 364;
  Label1.Height          = 36;
  Label1.Visible         = 1;
  Label1.Active          = 1;
  Label1.Caption         = Label1_Caption;
  Label1.FontName        = Tahoma26x33_Regular;
  Label1.Font_Color      = 0x07E0;
  Label1.VerticalText    = 0;
  Label1.OnUpPtr         = 0;
  Label1.OnDownPtr       = 0;
  Label1.OnClickPtr      = 0;
  Label1.OnPressPtr      = 0;

  Label3.OwnerScreen     = &Screen1;
  Label3.Order           = 1;
  Label3.Left            = 418;
  Label3.Top             = 510;
  Label3.Width           = 58;
  Label3.Height          = 15;
  Label3.Visible         = 1;
  Label3.Active          = 1;
  Label3.Caption         = Label3_Caption;
  Label3.FontName        = Tahoma11x13_Regular;
  Label3.Font_Color      = 0xFFFF;
  Label3.VerticalText    = 0;
  Label3.OnUpPtr         = 0;
  Label3.OnDownPtr       = 0;
  Label3.OnClickPtr      = 0;
  Label3.OnPressPtr      = 0;

  Label4.OwnerScreen     = &Screen1;
  Label4.Order           = 2;
  Label4.Left            = 418;
  Label4.Top             = 498;
  Label4.Width           = 58;
  Label4.Height          = 15;
  Label4.Visible         = 1;
  Label4.Active          = 1;
  Label4.Caption         = Label4_Caption;
  Label4.FontName        = Tahoma11x13_Regular;
  Label4.Font_Color      = 0xFFFF;
  Label4.VerticalText    = 0;
  Label4.OnUpPtr         = 0;
  Label4.OnDownPtr       = 0;
  Label4.OnClickPtr      = 0;
  Label4.OnPressPtr      = 0;

  Label5.OwnerScreen     = &Screen1;
  Label5.Order           = 3;
  Label5.Left            = 440;
  Label5.Top             = 565;
  Label5.Width           = 36;
  Label5.Height          = 15;
  Label5.Visible         = 1;
  Label5.Active          = 1;
  Label5.Caption         = Label5_Caption;
  Label5.FontName        = Tahoma11x13_Regular;
  Label5.Font_Color      = 0xFFFF;
  Label5.VerticalText    = 0;
  Label5.OnUpPtr         = 0;
  Label5.OnDownPtr       = 0;
  Label5.OnClickPtr      = 0;
  Label5.OnPressPtr      = 0;

  Label6.OwnerScreen     = &Screen1;
  Label6.Order           = 4;
  Label6.Left            = 446;
  Label6.Top             = 249;
  Label6.Width           = 30;
  Label6.Height          = 15;
  Label6.Visible         = 1;
  Label6.Active          = 1;
  Label6.Caption         = Label6_Caption;
  Label6.FontName        = Tahoma11x13_Regular;
  Label6.Font_Color      = 0xFFFF;
  Label6.VerticalText    = 0;
  Label6.OnUpPtr         = 0;
  Label6.OnDownPtr       = 0;
  Label6.OnClickPtr      = 0;
  Label6.OnPressPtr      = 0;

  Label7.OwnerScreen     = &Screen1;
  Label7.Order           = 5;
  Label7.Left            = 424;
  Label7.Top             = 341;
  Label7.Width           = 52;
  Label7.Height          = 15;
  Label7.Visible         = 1;
  Label7.Active          = 1;
  Label7.Caption         = Label7_Caption;
  Label7.FontName        = Tahoma11x13_Regular;
  Label7.Font_Color      = 0xFFFF;
  Label7.VerticalText    = 0;
  Label7.OnUpPtr         = 0;
  Label7.OnDownPtr       = 0;
  Label7.OnClickPtr      = 0;
  Label7.OnPressPtr      = 0;

  Label2.OwnerScreen     = &Screen1;
  Label2.Order           = 6;
  Label2.Left            = 431;
  Label2.Top             = 234;
  Label2.Width           = 45;
  Label2.Height          = 15;
  Label2.Visible         = 1;
  Label2.Active          = 1;
  Label2.Caption         = Label2_Caption;
  Label2.FontName        = Tahoma11x13_Regular;
  Label2.Font_Color      = 0xFFFF;
  Label2.VerticalText    = 0;
  Label2.OnUpPtr         = 0;
  Label2.OnDownPtr       = 0;
  Label2.OnClickPtr      = 0;
  Label2.OnPressPtr      = 0;

  Label8.OwnerScreen     = &Screen1;
  Label8.Order           = 7;
  Label8.Left            = 448;
  Label8.Top             = 524;
  Label8.Width           = 27;
  Label8.Height          = 15;
  Label8.Visible         = 1;
  Label8.Active          = 1;
  Label8.Caption         = Label8_Caption;
  Label8.FontName        = Tahoma11x13_Regular;
  Label8.Font_Color      = 0xFFFF;
  Label8.VerticalText    = 0;
  Label8.OnUpPtr         = 0;
  Label8.OnDownPtr       = 0;
  Label8.OnClickPtr      = 0;
  Label8.OnPressPtr      = 0;

  Label9.OwnerScreen     = &Screen1;
  Label9.Order           = 8;
  Label9.Left            = 448;
  Label9.Top             = 538;
  Label9.Width           = 27;
  Label9.Height          = 15;
  Label9.Visible         = 1;
  Label9.Active          = 1;
  Label9.Caption         = Label9_Caption;
  Label9.FontName        = Tahoma11x13_Regular;
  Label9.Font_Color      = 0xFFFF;
  Label9.VerticalText    = 0;
  Label9.OnUpPtr         = 0;
  Label9.OnDownPtr       = 0;
  Label9.OnClickPtr      = 0;
  Label9.OnPressPtr      = 0;

  Label10.OwnerScreen     = &Screen1;
  Label10.Order           = 9;
  Label10.Left            = 441;
  Label10.Top             = 551;
  Label10.Width           = 35;
  Label10.Height          = 15;
  Label10.Visible         = 1;
  Label10.Active          = 1;
  Label10.Caption         = Label10_Caption;
  Label10.FontName        = Tahoma11x13_Regular;
  Label10.Font_Color      = 0xFFFF;
  Label10.VerticalText    = 0;
  Label10.OnUpPtr         = 0;
  Label10.OnDownPtr       = 0;
  Label10.OnClickPtr      = 0;
  Label10.OnPressPtr      = 0;

  Label11.OwnerScreen     = &Screen1;
  Label11.Order           = 10;
  Label11.Left            = 420;
  Label11.Top             = 484;
  Label11.Width           = 55;
  Label11.Height          = 15;
  Label11.Visible         = 1;
  Label11.Active          = 1;
  Label11.Caption         = Label11_Caption;
  Label11.FontName        = Tahoma11x13_Regular;
  Label11.Font_Color      = 0xFFFF;
  Label11.VerticalText    = 0;
  Label11.OnUpPtr         = 0;
  Label11.OnDownPtr       = 0;
  Label11.OnClickPtr      = 0;
  Label11.OnPressPtr      = 0;

  Label12.OwnerScreen     = &Screen1;
  Label12.Order           = 11;
  Label12.Left            = 420;
  Label12.Top             = 472;
  Label12.Width           = 55;
  Label12.Height          = 15;
  Label12.Visible         = 1;
  Label12.Active          = 1;
  Label12.Caption         = Label12_Caption;
  Label12.FontName        = Tahoma11x13_Regular;
  Label12.Font_Color      = 0xFFFF;
  Label12.VerticalText    = 0;
  Label12.OnUpPtr         = 0;
  Label12.OnDownPtr       = 0;
  Label12.OnClickPtr      = 0;
  Label12.OnPressPtr      = 0;

  Label13.OwnerScreen     = &Screen1;
  Label13.Order           = 12;
  Label13.Left            = 420;
  Label13.Top             = 459;
  Label13.Width           = 55;
  Label13.Height          = 15;
  Label13.Visible         = 1;
  Label13.Active          = 1;
  Label13.Caption         = Label13_Caption;
  Label13.FontName        = Tahoma11x13_Regular;
  Label13.Font_Color      = 0xFFFF;
  Label13.VerticalText    = 0;
  Label13.OnUpPtr         = 0;
  Label13.OnDownPtr       = 0;
  Label13.OnClickPtr      = 0;
  Label13.OnPressPtr      = 0;

  Label14.OwnerScreen     = &Screen1;
  Label14.Order           = 13;
  Label14.Left            = 414;
  Label14.Top             = 445;
  Label14.Width           = 62;
  Label14.Height          = 15;
  Label14.Visible         = 1;
  Label14.Active          = 1;
  Label14.Caption         = Label14_Caption;
  Label14.FontName        = Tahoma11x13_Regular;
  Label14.Font_Color      = 0xFFFF;
  Label14.VerticalText    = 0;
  Label14.OnUpPtr         = 0;
  Label14.OnDownPtr       = 0;
  Label14.OnClickPtr      = 0;
  Label14.OnPressPtr      = 0;

  Label15.OwnerScreen     = &Screen1;
  Label15.Order           = 14;
  Label15.Left            = 416;
  Label15.Top             = 432;
  Label15.Width           = 59;
  Label15.Height          = 15;
  Label15.Visible         = 1;
  Label15.Active          = 1;
  Label15.Caption         = Label15_Caption;
  Label15.FontName        = Tahoma11x13_Regular;
  Label15.Font_Color      = 0xFFFF;
  Label15.VerticalText    = 0;
  Label15.OnUpPtr         = 0;
  Label15.OnDownPtr       = 0;
  Label15.OnClickPtr      = 0;
  Label15.OnPressPtr      = 0;

  Label16.OwnerScreen     = &Screen1;
  Label16.Order           = 15;
  Label16.Left            = 416;
  Label16.Top             = 419;
  Label16.Width           = 59;
  Label16.Height          = 15;
  Label16.Visible         = 1;
  Label16.Active          = 1;
  Label16.Caption         = Label16_Caption;
  Label16.FontName        = Tahoma11x13_Regular;
  Label16.Font_Color      = 0xFFFF;
  Label16.VerticalText    = 0;
  Label16.OnUpPtr         = 0;
  Label16.OnDownPtr       = 0;
  Label16.OnClickPtr      = 0;
  Label16.OnPressPtr      = 0;

  Label17.OwnerScreen     = &Screen1;
  Label17.Order           = 16;
  Label17.Left            = 414;
  Label17.Top             = 407;
  Label17.Width           = 61;
  Label17.Height          = 15;
  Label17.Visible         = 1;
  Label17.Active          = 1;
  Label17.Caption         = Label17_Caption;
  Label17.FontName        = Tahoma11x13_Regular;
  Label17.Font_Color      = 0xFFFF;
  Label17.VerticalText    = 0;
  Label17.OnUpPtr         = 0;
  Label17.OnDownPtr       = 0;
  Label17.OnClickPtr      = 0;
  Label17.OnPressPtr      = 0;

  Label18.OwnerScreen     = &Screen1;
  Label18.Order           = 17;
  Label18.Left            = 414;
  Label18.Top             = 393;
  Label18.Width           = 61;
  Label18.Height          = 15;
  Label18.Visible         = 1;
  Label18.Active          = 1;
  Label18.Caption         = Label18_Caption;
  Label18.FontName        = Tahoma11x13_Regular;
  Label18.Font_Color      = 0xFFFF;
  Label18.VerticalText    = 0;
  Label18.OnUpPtr         = 0;
  Label18.OnDownPtr       = 0;
  Label18.OnClickPtr      = 0;
  Label18.OnPressPtr      = 0;

  Label19.OwnerScreen     = &Screen1;
  Label19.Order           = 18;
  Label19.Left            = 414;
  Label19.Top             = 381;
  Label19.Width           = 61;
  Label19.Height          = 15;
  Label19.Visible         = 1;
  Label19.Active          = 1;
  Label19.Caption         = Label19_Caption;
  Label19.FontName        = Tahoma11x13_Regular;
  Label19.Font_Color      = 0xFFFF;
  Label19.VerticalText    = 0;
  Label19.OnUpPtr         = 0;
  Label19.OnDownPtr       = 0;
  Label19.OnClickPtr      = 0;
  Label19.OnPressPtr      = 0;

  Label20.OwnerScreen     = &Screen1;
  Label20.Order           = 19;
  Label20.Left            = 414;
  Label20.Top             = 369;
  Label20.Width           = 61;
  Label20.Height          = 15;
  Label20.Visible         = 1;
  Label20.Active          = 1;
  Label20.Caption         = Label20_Caption;
  Label20.FontName        = Tahoma11x13_Regular;
  Label20.Font_Color      = 0xFFFF;
  Label20.VerticalText    = 0;
  Label20.OnUpPtr         = 0;
  Label20.OnDownPtr       = 0;
  Label20.OnClickPtr      = 0;
  Label20.OnPressPtr      = 0;

  Label21.OwnerScreen     = &Screen1;
  Label21.Order           = 20;
  Label21.Left            = 411;
  Label21.Top             = 354;
  Label21.Width           = 65;
  Label21.Height          = 15;
  Label21.Visible         = 1;
  Label21.Active          = 1;
  Label21.Caption         = Label21_Caption;
  Label21.FontName        = Tahoma11x13_Regular;
  Label21.Font_Color      = 0xFFFF;
  Label21.VerticalText    = 0;
  Label21.OnUpPtr         = 0;
  Label21.OnDownPtr       = 0;
  Label21.OnClickPtr      = 0;
  Label21.OnPressPtr      = 0;

  Label22.OwnerScreen     = &Screen1;
  Label22.Order           = 21;
  Label22.Left            = 403;
  Label22.Top             = 327;
  Label22.Width           = 73;
  Label22.Height          = 15;
  Label22.Visible         = 1;
  Label22.Active          = 1;
  Label22.Caption         = Label22_Caption;
  Label22.FontName        = Tahoma11x13_Regular;
  Label22.Font_Color      = 0xFFFF;
  Label22.VerticalText    = 0;
  Label22.OnUpPtr         = 0;
  Label22.OnDownPtr       = 0;
  Label22.OnClickPtr      = 0;
  Label22.OnPressPtr      = 0;

  Label23.OwnerScreen     = &Screen1;
  Label23.Order           = 22;
  Label23.Left            = 403;
  Label23.Top             = 314;
  Label23.Width           = 73;
  Label23.Height          = 15;
  Label23.Visible         = 1;
  Label23.Active          = 1;
  Label23.Caption         = Label23_Caption;
  Label23.FontName        = Tahoma11x13_Regular;
  Label23.Font_Color      = 0xFFFF;
  Label23.VerticalText    = 0;
  Label23.OnUpPtr         = 0;
  Label23.OnDownPtr       = 0;
  Label23.OnClickPtr      = 0;
  Label23.OnPressPtr      = 0;

  Label24.OwnerScreen     = &Screen1;
  Label24.Order           = 23;
  Label24.Left            = 403;
  Label24.Top             = 300;
  Label24.Width           = 73;
  Label24.Height          = 15;
  Label24.Visible         = 1;
  Label24.Active          = 1;
  Label24.Caption         = Label24_Caption;
  Label24.FontName        = Tahoma11x13_Regular;
  Label24.Font_Color      = 0xFFFF;
  Label24.VerticalText    = 0;
  Label24.OnUpPtr         = 0;
  Label24.OnDownPtr       = 0;
  Label24.OnClickPtr      = 0;
  Label24.OnPressPtr      = 0;

  Label25.OwnerScreen     = &Screen1;
  Label25.Order           = 24;
  Label25.Left            = 403;
  Label25.Top             = 288;
  Label25.Width           = 72;
  Label25.Height          = 15;
  Label25.Visible         = 1;
  Label25.Active          = 1;
  Label25.Caption         = Label25_Caption;
  Label25.FontName        = Tahoma11x13_Regular;
  Label25.Font_Color      = 0xFFFF;
  Label25.VerticalText    = 0;
  Label25.OnUpPtr         = 0;
  Label25.OnDownPtr       = 0;
  Label25.OnClickPtr      = 0;
  Label25.OnPressPtr      = 0;

  Label26.OwnerScreen     = &Screen1;
  Label26.Order           = 25;
  Label26.Left            = 403;
  Label26.Top             = 277;
  Label26.Width           = 72;
  Label26.Height          = 15;
  Label26.Visible         = 1;
  Label26.Active          = 1;
  Label26.Caption         = Label26_Caption;
  Label26.FontName        = Tahoma11x13_Regular;
  Label26.Font_Color      = 0xFFFF;
  Label26.VerticalText    = 0;
  Label26.OnUpPtr         = 0;
  Label26.OnDownPtr       = 0;
  Label26.OnClickPtr      = 0;
  Label26.OnPressPtr      = 0;

  Label27.OwnerScreen     = &Screen1;
  Label27.Order           = 26;
  Label27.Left            = 403;
  Label27.Top             = 264;
  Label27.Width           = 73;
  Label27.Height          = 15;
  Label27.Visible         = 1;
  Label27.Active          = 1;
  Label27.Caption         = Label27_Caption;
  Label27.FontName        = Tahoma11x13_Regular;
  Label27.Font_Color      = 0xFFFF;
  Label27.VerticalText    = 0;
  Label27.OnUpPtr         = 0;
  Label27.OnDownPtr       = 0;
  Label27.OnClickPtr      = 0;
  Label27.OnPressPtr      = 0;

  Label28.OwnerScreen     = &Screen1;
  Label28.Order           = 27;
  Label28.Left            = 0;
  Label28.Top             = 236;
  Label28.Width           = 32;
  Label28.Height          = 15;
  Label28.Visible         = 1;
  Label28.Active          = 1;
  Label28.Caption         = Label28_Caption;
  Label28.FontName        = Tahoma11x13_Regular;
  Label28.Font_Color      = 0xFFFF;
  Label28.VerticalText    = 0;
  Label28.OnUpPtr         = 0;
  Label28.OnDownPtr       = 0;
  Label28.OnClickPtr      = 0;
  Label28.OnPressPtr      = 0;

  Label29.OwnerScreen     = &Screen1;
  Label29.Order           = 28;
  Label29.Left            = 0;
  Label29.Top             = 248;
  Label29.Width           = 35;
  Label29.Height          = 15;
  Label29.Visible         = 1;
  Label29.Active          = 1;
  Label29.Caption         = Label29_Caption;
  Label29.FontName        = Tahoma11x13_Regular;
  Label29.Font_Color      = 0xFFFF;
  Label29.VerticalText    = 0;
  Label29.OnUpPtr         = 0;
  Label29.OnDownPtr       = 0;
  Label29.OnClickPtr      = 0;
  Label29.OnPressPtr      = 0;

  Label30.OwnerScreen     = &Screen1;
  Label30.Order           = 29;
  Label30.Left            = 0;
  Label30.Top             = 260;
  Label30.Width           = 75;
  Label30.Height          = 15;
  Label30.Visible         = 1;
  Label30.Active          = 1;
  Label30.Caption         = Label30_Caption;
  Label30.FontName        = Tahoma11x13_Regular;
  Label30.Font_Color      = 0xFFFF;
  Label30.VerticalText    = 0;
  Label30.OnUpPtr         = 0;
  Label30.OnDownPtr       = 0;
  Label30.OnClickPtr      = 0;
  Label30.OnPressPtr      = 0;

  Label31.OwnerScreen     = &Screen1;
  Label31.Order           = 30;
  Label31.Left            = 0;
  Label31.Top             = 273;
  Label31.Width           = 76;
  Label31.Height          = 15;
  Label31.Visible         = 1;
  Label31.Active          = 1;
  Label31.Caption         = Label31_Caption;
  Label31.FontName        = Tahoma11x13_Regular;
  Label31.Font_Color      = 0xFFFF;
  Label31.VerticalText    = 0;
  Label31.OnUpPtr         = 0;
  Label31.OnDownPtr       = 0;
  Label31.OnClickPtr      = 0;
  Label31.OnPressPtr      = 0;

  Label32.OwnerScreen     = &Screen1;
  Label32.Order           = 31;
  Label32.Left            = 0;
  Label32.Top             = 286;
  Label32.Width           = 67;
  Label32.Height          = 15;
  Label32.Visible         = 1;
  Label32.Active          = 1;
  Label32.Caption         = Label32_Caption;
  Label32.FontName        = Tahoma11x13_Regular;
  Label32.Font_Color      = 0xFFFF;
  Label32.VerticalText    = 0;
  Label32.OnUpPtr         = 0;
  Label32.OnDownPtr       = 0;
  Label32.OnClickPtr      = 0;
  Label32.OnPressPtr      = 0;

  Label33.OwnerScreen     = &Screen1;
  Label33.Order           = 32;
  Label33.Left            = 0;
  Label33.Top             = 301;
  Label33.Width           = 69;
  Label33.Height          = 15;
  Label33.Visible         = 1;
  Label33.Active          = 1;
  Label33.Caption         = Label33_Caption;
  Label33.FontName        = Tahoma11x13_Regular;
  Label33.Font_Color      = 0xFFFF;
  Label33.VerticalText    = 0;
  Label33.OnUpPtr         = 0;
  Label33.OnDownPtr       = 0;
  Label33.OnClickPtr      = 0;
  Label33.OnPressPtr      = 0;

  Label34.OwnerScreen     = &Screen1;
  Label34.Order           = 33;
  Label34.Left            = 0;
  Label34.Top             = 313;
  Label34.Width           = 65;
  Label34.Height          = 15;
  Label34.Visible         = 1;
  Label34.Active          = 1;
  Label34.Caption         = Label34_Caption;
  Label34.FontName        = Tahoma11x13_Regular;
  Label34.Font_Color      = 0xFFFF;
  Label34.VerticalText    = 0;
  Label34.OnUpPtr         = 0;
  Label34.OnDownPtr       = 0;
  Label34.OnClickPtr      = 0;
  Label34.OnPressPtr      = 0;

  Label35.OwnerScreen     = &Screen1;
  Label35.Order           = 34;
  Label35.Left            = 0;
  Label35.Top             = 326;
  Label35.Width           = 65;
  Label35.Height          = 15;
  Label35.Visible         = 1;
  Label35.Active          = 1;
  Label35.Caption         = Label35_Caption;
  Label35.FontName        = Tahoma11x13_Regular;
  Label35.Font_Color      = 0xFFFF;
  Label35.VerticalText    = 0;
  Label35.OnUpPtr         = 0;
  Label35.OnDownPtr       = 0;
  Label35.OnClickPtr      = 0;
  Label35.OnPressPtr      = 0;

  Label36.OwnerScreen     = &Screen1;
  Label36.Order           = 35;
  Label36.Left            = 0;
  Label36.Top             = 340;
  Label36.Width           = 65;
  Label36.Height          = 15;
  Label36.Visible         = 1;
  Label36.Active          = 1;
  Label36.Caption         = Label36_Caption;
  Label36.FontName        = Tahoma11x13_Regular;
  Label36.Font_Color      = 0xFFFF;
  Label36.VerticalText    = 0;
  Label36.OnUpPtr         = 0;
  Label36.OnDownPtr       = 0;
  Label36.OnClickPtr      = 0;
  Label36.OnPressPtr      = 0;

  Label37.OwnerScreen     = &Screen1;
  Label37.Order           = 36;
  Label37.Left            = 0;
  Label37.Top             = 354;
  Label37.Width           = 65;
  Label37.Height          = 15;
  Label37.Visible         = 1;
  Label37.Active          = 1;
  Label37.Caption         = Label37_Caption;
  Label37.FontName        = Tahoma11x13_Regular;
  Label37.Font_Color      = 0xFFFF;
  Label37.VerticalText    = 0;
  Label37.OnUpPtr         = 0;
  Label37.OnDownPtr       = 0;
  Label37.OnClickPtr      = 0;
  Label37.OnPressPtr      = 0;

  Label38.OwnerScreen     = &Screen1;
  Label38.Order           = 37;
  Label38.Left            = 0;
  Label38.Top             = 367;
  Label38.Width           = 57;
  Label38.Height          = 15;
  Label38.Visible         = 1;
  Label38.Active          = 1;
  Label38.Caption         = Label38_Caption;
  Label38.FontName        = Tahoma11x13_Regular;
  Label38.Font_Color      = 0xFFFF;
  Label38.VerticalText    = 0;
  Label38.OnUpPtr         = 0;
  Label38.OnDownPtr       = 0;
  Label38.OnClickPtr      = 0;
  Label38.OnPressPtr      = 0;

  Label39.OwnerScreen     = &Screen1;
  Label39.Order           = 38;
  Label39.Left            = 0;
  Label39.Top             = 380;
  Label39.Width           = 57;
  Label39.Height          = 15;
  Label39.Visible         = 1;
  Label39.Active          = 1;
  Label39.Caption         = Label39_Caption;
  Label39.FontName        = Tahoma11x13_Regular;
  Label39.Font_Color      = 0xFFFF;
  Label39.VerticalText    = 0;
  Label39.OnUpPtr         = 0;
  Label39.OnDownPtr       = 0;
  Label39.OnClickPtr      = 0;
  Label39.OnPressPtr      = 0;

  Label40.OwnerScreen     = &Screen1;
  Label40.Order           = 39;
  Label40.Left            = 0;
  Label40.Top             = 393;
  Label40.Width           = 50;
  Label40.Height          = 15;
  Label40.Visible         = 1;
  Label40.Active          = 1;
  Label40.Caption         = Label40_Caption;
  Label40.FontName        = Tahoma11x13_Regular;
  Label40.Font_Color      = 0xFFFF;
  Label40.VerticalText    = 0;
  Label40.OnUpPtr         = 0;
  Label40.OnDownPtr       = 0;
  Label40.OnClickPtr      = 0;
  Label40.OnPressPtr      = 0;

  Label41.OwnerScreen     = &Screen1;
  Label41.Order           = 40;
  Label41.Left            = 0;
  Label41.Top             = 407;
  Label41.Width           = 50;
  Label41.Height          = 15;
  Label41.Visible         = 1;
  Label41.Active          = 1;
  Label41.Caption         = Label41_Caption;
  Label41.FontName        = Tahoma11x13_Regular;
  Label41.Font_Color      = 0xFFFF;
  Label41.VerticalText    = 0;
  Label41.OnUpPtr         = 0;
  Label41.OnDownPtr       = 0;
  Label41.OnClickPtr      = 0;
  Label41.OnPressPtr      = 0;

  Label42.OwnerScreen     = &Screen1;
  Label42.Order           = 41;
  Label42.Left            = 0;
  Label42.Top             = 421;
  Label42.Width           = 50;
  Label42.Height          = 15;
  Label42.Visible         = 1;
  Label42.Active          = 1;
  Label42.Caption         = Label42_Caption;
  Label42.FontName        = Tahoma11x13_Regular;
  Label42.Font_Color      = 0xFFFF;
  Label42.VerticalText    = 0;
  Label42.OnUpPtr         = 0;
  Label42.OnDownPtr       = 0;
  Label42.OnClickPtr      = 0;
  Label42.OnPressPtr      = 0;

  Label43.OwnerScreen     = &Screen1;
  Label43.Order           = 42;
  Label43.Left            = 0;
  Label43.Top             = 434;
  Label43.Width           = 50;
  Label43.Height          = 15;
  Label43.Visible         = 1;
  Label43.Active          = 1;
  Label43.Caption         = Label43_Caption;
  Label43.FontName        = Tahoma11x13_Regular;
  Label43.Font_Color      = 0xFFFF;
  Label43.VerticalText    = 0;
  Label43.OnUpPtr         = 0;
  Label43.OnDownPtr       = 0;
  Label43.OnClickPtr      = 0;
  Label43.OnPressPtr      = 0;

  Label44.OwnerScreen     = &Screen1;
  Label44.Order           = 43;
  Label44.Left            = 0;
  Label44.Top             = 447;
  Label44.Width           = 55;
  Label44.Height          = 15;
  Label44.Visible         = 1;
  Label44.Active          = 1;
  Label44.Caption         = Label44_Caption;
  Label44.FontName        = Tahoma11x13_Regular;
  Label44.Font_Color      = 0xFFFF;
  Label44.VerticalText    = 0;
  Label44.OnUpPtr         = 0;
  Label44.OnDownPtr       = 0;
  Label44.OnClickPtr      = 0;
  Label44.OnPressPtr      = 0;

  Label45.OwnerScreen     = &Screen1;
  Label45.Order           = 44;
  Label45.Left            = 0;
  Label45.Top             = 461;
  Label45.Width           = 55;
  Label45.Height          = 15;
  Label45.Visible         = 1;
  Label45.Active          = 1;
  Label45.Caption         = Label45_Caption;
  Label45.FontName        = Tahoma11x13_Regular;
  Label45.Font_Color      = 0xFFFF;
  Label45.VerticalText    = 0;
  Label45.OnUpPtr         = 0;
  Label45.OnDownPtr       = 0;
  Label45.OnClickPtr      = 0;
  Label45.OnPressPtr      = 0;

  Label46.OwnerScreen     = &Screen1;
  Label46.Order           = 45;
  Label46.Left            = 0;
  Label46.Top             = 473;
  Label46.Width           = 67;
  Label46.Height          = 15;
  Label46.Visible         = 1;
  Label46.Active          = 1;
  Label46.Caption         = Label46_Caption;
  Label46.FontName        = Tahoma11x13_Regular;
  Label46.Font_Color      = 0xFFFF;
  Label46.VerticalText    = 0;
  Label46.OnUpPtr         = 0;
  Label46.OnDownPtr       = 0;
  Label46.OnClickPtr      = 0;
  Label46.OnPressPtr      = 0;

  Label47.OwnerScreen     = &Screen1;
  Label47.Order           = 46;
  Label47.Left            = 0;
  Label47.Top             = 486;
  Label47.Width           = 67;
  Label47.Height          = 15;
  Label47.Visible         = 1;
  Label47.Active          = 1;
  Label47.Caption         = Label47_Caption;
  Label47.FontName        = Tahoma11x13_Regular;
  Label47.Font_Color      = 0xFFFF;
  Label47.VerticalText    = 0;
  Label47.OnUpPtr         = 0;
  Label47.OnDownPtr       = 0;
  Label47.OnClickPtr      = 0;
  Label47.OnPressPtr      = 0;

  Label48.OwnerScreen     = &Screen1;
  Label48.Order           = 47;
  Label48.Left            = 0;
  Label48.Top             = 498;
  Label48.Width           = 66;
  Label48.Height          = 15;
  Label48.Visible         = 1;
  Label48.Active          = 1;
  Label48.Caption         = Label48_Caption;
  Label48.FontName        = Tahoma11x13_Regular;
  Label48.Font_Color      = 0xFFFF;
  Label48.VerticalText    = 0;
  Label48.OnUpPtr         = 0;
  Label48.OnDownPtr       = 0;
  Label48.OnClickPtr      = 0;
  Label48.OnPressPtr      = 0;

  Label49.OwnerScreen     = &Screen1;
  Label49.Order           = 48;
  Label49.Left            = 0;
  Label49.Top             = 510;
  Label49.Width           = 67;
  Label49.Height          = 15;
  Label49.Visible         = 1;
  Label49.Active          = 1;
  Label49.Caption         = Label49_Caption;
  Label49.FontName        = Tahoma11x13_Regular;
  Label49.Font_Color      = 0xFFFF;
  Label49.VerticalText    = 0;
  Label49.OnUpPtr         = 0;
  Label49.OnDownPtr       = 0;
  Label49.OnClickPtr      = 0;
  Label49.OnPressPtr      = 0;

  Label50.OwnerScreen     = &Screen1;
  Label50.Order           = 49;
  Label50.Left            = 0;
  Label50.Top             = 523;
  Label50.Width           = 56;
  Label50.Height          = 15;
  Label50.Visible         = 1;
  Label50.Active          = 1;
  Label50.Caption         = Label50_Caption;
  Label50.FontName        = Tahoma11x13_Regular;
  Label50.Font_Color      = 0xFFFF;
  Label50.VerticalText    = 0;
  Label50.OnUpPtr         = 0;
  Label50.OnDownPtr       = 0;
  Label50.OnClickPtr      = 0;
  Label50.OnPressPtr      = 0;

  Label51.OwnerScreen     = &Screen1;
  Label51.Order           = 50;
  Label51.Left            = 0;
  Label51.Top             = 536;
  Label51.Width           = 56;
  Label51.Height          = 15;
  Label51.Visible         = 1;
  Label51.Active          = 1;
  Label51.Caption         = Label51_Caption;
  Label51.FontName        = Tahoma11x13_Regular;
  Label51.Font_Color      = 0xFFFF;
  Label51.VerticalText    = 0;
  Label51.OnUpPtr         = 0;
  Label51.OnDownPtr       = 0;
  Label51.OnClickPtr      = 0;
  Label51.OnPressPtr      = 0;

  Label52.OwnerScreen     = &Screen1;
  Label52.Order           = 51;
  Label52.Left            = 0;
  Label52.Top             = 549;
  Label52.Width           = 36;
  Label52.Height          = 15;
  Label52.Visible         = 1;
  Label52.Active          = 1;
  Label52.Caption         = Label52_Caption;
  Label52.FontName        = Tahoma11x13_Regular;
  Label52.Font_Color      = 0xFFFF;
  Label52.VerticalText    = 0;
  Label52.OnUpPtr         = 0;
  Label52.OnDownPtr       = 0;
  Label52.OnClickPtr      = 0;
  Label52.OnPressPtr      = 0;

  Label53.OwnerScreen     = &Screen1;
  Label53.Order           = 52;
  Label53.Left            = 0;
  Label53.Top             = 563;
  Label53.Width           = 99;
  Label53.Height          = 15;
  Label53.Visible         = 1;
  Label53.Active          = 1;
  Label53.Caption         = Label53_Caption;
  Label53.FontName        = Tahoma11x13_Regular;
  Label53.Font_Color      = 0xFFFF;
  Label53.VerticalText    = 0;
  Label53.OnUpPtr         = 0;
  Label53.OnDownPtr       = 0;
  Label53.OnClickPtr      = 0;
  Label53.OnPressPtr      = 0;

  Label54.OwnerScreen     = &Screen1;
  Label54.Order           = 53;
  Label54.Left            = 4;
  Label54.Top             = 652;
  Label54.Width           = 28;
  Label54.Height          = 15;
  Label54.Visible         = 1;
  Label54.Active          = 1;
  Label54.Caption         = Label54_Caption;
  Label54.FontName        = Tahoma11x13_Regular;
  Label54.Font_Color      = 0xFFFF;
  Label54.VerticalText    = 0;
  Label54.OnUpPtr         = 0;
  Label54.OnDownPtr       = 0;
  Label54.OnClickPtr      = 0;
  Label54.OnPressPtr      = 0;

  Label55.OwnerScreen     = &Screen1;
  Label55.Order           = 54;
  Label55.Left            = 0;
  Label55.Top             = 665;
  Label55.Width           = 32;
  Label55.Height          = 15;
  Label55.Visible         = 1;
  Label55.Active          = 1;
  Label55.Caption         = Label55_Caption;
  Label55.FontName        = Tahoma11x13_Regular;
  Label55.Font_Color      = 0xFFFF;
  Label55.VerticalText    = 0;
  Label55.OnUpPtr         = 0;
  Label55.OnDownPtr       = 0;
  Label55.OnClickPtr      = 0;
  Label55.OnPressPtr      = 0;

  Label56.OwnerScreen     = &Screen1;
  Label56.Order           = 55;
  Label56.Left            = 310;
  Label56.Top             = 7;
  Label56.Width           = 56;
  Label56.Height          = 15;
  Label56.Visible         = 1;
  Label56.Active          = 1;
  Label56.Caption         = Label56_Caption;
  Label56.FontName        = Tahoma11x13_Regular;
  Label56.Font_Color      = 0xFFFF;
  Label56.VerticalText    = 0;
  Label56.OnUpPtr         = 0;
  Label56.OnDownPtr       = 0;
  Label56.OnClickPtr      = 0;
  Label56.OnPressPtr      = 0;

  Label57.OwnerScreen     = &Screen1;
  Label57.Order           = 56;
  Label57.Left            = 310;
  Label57.Top             = 19;
  Label57.Width           = 85;
  Label57.Height          = 15;
  Label57.Visible         = 1;
  Label57.Active          = 1;
  Label57.Caption         = Label57_Caption;
  Label57.FontName        = Tahoma11x13_Regular;
  Label57.Font_Color      = 0xFFFF;
  Label57.VerticalText    = 0;
  Label57.OnUpPtr         = 0;
  Label57.OnDownPtr       = 0;
  Label57.OnClickPtr      = 0;
  Label57.OnPressPtr      = 0;

  Label58.OwnerScreen     = &Screen1;
  Label58.Order           = 57;
  Label58.Left            = 310;
  Label58.Top             = 32;
  Label58.Width           = 84;
  Label58.Height          = 15;
  Label58.Visible         = 1;
  Label58.Active          = 1;
  Label58.Caption         = Label58_Caption;
  Label58.FontName        = Tahoma11x13_Regular;
  Label58.Font_Color      = 0xFFFF;
  Label58.VerticalText    = 0;
  Label58.OnUpPtr         = 0;
  Label58.OnDownPtr       = 0;
  Label58.OnClickPtr      = 0;
  Label58.OnPressPtr      = 0;

  Label59.OwnerScreen     = &Screen1;
  Label59.Order           = 58;
  Label59.Left            = 249;
  Label59.Top             = 10;
  Label59.Width           = 34;
  Label59.Height          = 15;
  Label59.Visible         = 1;
  Label59.Active          = 1;
  Label59.Caption         = Label59_Caption;
  Label59.FontName        = Tahoma11x13_Regular;
  Label59.Font_Color      = 0xFB76;
  Label59.VerticalText    = 0;
  Label59.OnUpPtr         = 0;
  Label59.OnDownPtr       = 0;
  Label59.OnClickPtr      = 0;
  Label59.OnPressPtr      = 0;

  Label60.OwnerScreen     = &Screen1;
  Label60.Order           = 59;
  Label60.Left            = 51;
  Label60.Top             = 6;
  Label60.Width           = 70;
  Label60.Height          = 15;
  Label60.Visible         = 1;
  Label60.Active          = 1;
  Label60.Caption         = Label60_Caption;
  Label60.FontName        = Tahoma11x13_Regular;
  Label60.Font_Color      = 0xFFFF;
  Label60.VerticalText    = 0;
  Label60.OnUpPtr         = 0;
  Label60.OnDownPtr       = 0;
  Label60.OnClickPtr      = 0;
  Label60.OnPressPtr      = 0;

  Label61.OwnerScreen     = &Screen1;
  Label61.Order           = 60;
  Label61.Left            = 5;
  Label61.Top             = 154;
  Label61.Width           = 50;
  Label61.Height          = 15;
  Label61.Visible         = 1;
  Label61.Active          = 1;
  Label61.Caption         = Label61_Caption;
  Label61.FontName        = Tahoma11x13_Regular;
  Label61.Font_Color      = 0xFFFF;
  Label61.VerticalText    = 0;
  Label61.OnUpPtr         = 0;
  Label61.OnDownPtr       = 0;
  Label61.OnClickPtr      = 0;
  Label61.OnPressPtr      = 0;

  Label62.OwnerScreen     = &Screen1;
  Label62.Order           = 61;
  Label62.Left            = 238;
  Label62.Top             = 675;
  Label62.Width           = 96;
  Label62.Height          = 15;
  Label62.Visible         = 1;
  Label62.Active          = 1;
  Label62.Caption         = Label62_Caption;
  Label62.FontName        = Tahoma11x13_Regular;
  Label62.Font_Color      = 0xFFE0;
  Label62.VerticalText    = 0;
  Label62.OnUpPtr         = 0;
  Label62.OnDownPtr       = 0;
  Label62.OnClickPtr      = 0;
  Label62.OnPressPtr      = 0;

  Label63.OwnerScreen     = &Screen1;
  Label63.Order           = 62;
  Label63.Left            = 247;
  Label63.Top             = 690;
  Label63.Width           = 82;
  Label63.Height          = 15;
  Label63.Visible         = 1;
  Label63.Active          = 1;
  Label63.Caption         = Label63_Caption;
  Label63.FontName        = Tahoma11x13_Regular;
  Label63.Font_Color      = 0xFFE0;
  Label63.VerticalText    = 0;
  Label63.OnUpPtr         = 0;
  Label63.OnDownPtr       = 0;
  Label63.OnClickPtr      = 0;
  Label63.OnPressPtr      = 0;

  Label64.OwnerScreen     = &Screen1;
  Label64.Order           = 63;
  Label64.Left            = 247;
  Label64.Top             = 701;
  Label64.Width           = 100;
  Label64.Height          = 15;
  Label64.Visible         = 1;
  Label64.Active          = 1;
  Label64.Caption         = Label64_Caption;
  Label64.FontName        = Tahoma11x13_Regular;
  Label64.Font_Color      = 0xFFE0;
  Label64.VerticalText    = 0;
  Label64.OnUpPtr         = 0;
  Label64.OnDownPtr       = 0;
  Label64.OnClickPtr      = 0;
  Label64.OnPressPtr      = 0;

  Label65.OwnerScreen     = &Screen1;
  Label65.Order           = 64;
  Label65.Left            = 247;
  Label65.Top             = 714;
  Label65.Width           = 115;
  Label65.Height          = 15;
  Label65.Visible         = 1;
  Label65.Active          = 1;
  Label65.Caption         = Label65_Caption;
  Label65.FontName        = Tahoma11x13_Regular;
  Label65.Font_Color      = 0xFFE0;
  Label65.VerticalText    = 0;
  Label65.OnUpPtr         = 0;
  Label65.OnDownPtr       = 0;
  Label65.OnClickPtr      = 0;
  Label65.OnPressPtr      = 0;

  Label66.OwnerScreen     = &Screen1;
  Label66.Order           = 65;
  Label66.Left            = 247;
  Label66.Top             = 726;
  Label66.Width           = 89;
  Label66.Height          = 15;
  Label66.Visible         = 1;
  Label66.Active          = 1;
  Label66.Caption         = Label66_Caption;
  Label66.FontName        = Tahoma11x13_Regular;
  Label66.Font_Color      = 0xFFE0;
  Label66.VerticalText    = 0;
  Label66.OnUpPtr         = 0;
  Label66.OnDownPtr       = 0;
  Label66.OnClickPtr      = 0;
  Label66.OnPressPtr      = 0;

  Label67.OwnerScreen     = &Screen1;
  Label67.Order           = 66;
  Label67.Left            = 247;
  Label67.Top             = 737;
  Label67.Width           = 89;
  Label67.Height          = 15;
  Label67.Visible         = 1;
  Label67.Active          = 1;
  Label67.Caption         = Label67_Caption;
  Label67.FontName        = Tahoma11x13_Regular;
  Label67.Font_Color      = 0xFFE0;
  Label67.VerticalText    = 0;
  Label67.OnUpPtr         = 0;
  Label67.OnDownPtr       = 0;
  Label67.OnClickPtr      = 0;
  Label67.OnPressPtr      = 0;

  Label68.OwnerScreen     = &Screen1;
  Label68.Order           = 67;
  Label68.Left            = 247;
  Label68.Top             = 749;
  Label68.Width           = 89;
  Label68.Height          = 15;
  Label68.Visible         = 1;
  Label68.Active          = 1;
  Label68.Caption         = Label68_Caption;
  Label68.FontName        = Tahoma11x13_Regular;
  Label68.Font_Color      = 0xFFE0;
  Label68.VerticalText    = 0;
  Label68.OnUpPtr         = 0;
  Label68.OnDownPtr       = 0;
  Label68.OnClickPtr      = 0;
  Label68.OnPressPtr      = 0;

  Label69.OwnerScreen     = &Screen1;
  Label69.Order           = 68;
  Label69.Left            = 247;
  Label69.Top             = 760;
  Label69.Width           = 115;
  Label69.Height          = 15;
  Label69.Visible         = 1;
  Label69.Active          = 1;
  Label69.Caption         = Label69_Caption;
  Label69.FontName        = Tahoma11x13_Regular;
  Label69.Font_Color      = 0xFFE0;
  Label69.VerticalText    = 0;
  Label69.OnUpPtr         = 0;
  Label69.OnDownPtr       = 0;
  Label69.OnClickPtr      = 0;
  Label69.OnPressPtr      = 0;

  Label70.OwnerScreen     = &Screen1;
  Label70.Order           = 69;
  Label70.Left            = 247;
  Label70.Top             = 771;
  Label70.Width           = 111;
  Label70.Height          = 15;
  Label70.Visible         = 1;
  Label70.Active          = 1;
  Label70.Caption         = Label70_Caption;
  Label70.FontName        = Tahoma11x13_Regular;
  Label70.Font_Color      = 0xFFE0;
  Label70.VerticalText    = 0;
  Label70.OnUpPtr         = 0;
  Label70.OnDownPtr       = 0;
  Label70.OnClickPtr      = 0;
  Label70.OnPressPtr      = 0;

  Label71.OwnerScreen     = &Screen1;
  Label71.Order           = 70;
  Label71.Left            = 230;
  Label71.Top             = 785;
  Label71.Width           = 105;
  Label71.Height          = 15;
  Label71.Visible         = 1;
  Label71.Active          = 1;
  Label71.Caption         = Label71_Caption;
  Label71.FontName        = Tahoma11x13_Regular;
  Label71.Font_Color      = 0xFFE0;
  Label71.VerticalText    = 0;
  Label71.OnUpPtr         = 0;
  Label71.OnDownPtr       = 0;
  Label71.OnClickPtr      = 0;
  Label71.OnPressPtr      = 0;

  Label72.OwnerScreen     = &Screen1;
  Label72.Order           = 71;
  Label72.Left            = 374;
  Label72.Top             = 784;
  Label72.Width           = 45;
  Label72.Height          = 15;
  Label72.Visible         = 1;
  Label72.Active          = 1;
  Label72.Caption         = Label72_Caption;
  Label72.FontName        = Tahoma11x13_Regular;
  Label72.Font_Color      = 0xFFE0;
  Label72.VerticalText    = 0;
  Label72.OnUpPtr         = 0;
  Label72.OnDownPtr       = 0;
  Label72.OnClickPtr      = 0;
  Label72.OnPressPtr      = 0;

  Label73.OwnerScreen     = &Screen1;
  Label73.Order           = 72;
  Label73.Left            = 454;
  Label73.Top             = 137;
  Label73.Width           = 19;
  Label73.Height          = 15;
  Label73.Visible         = 1;
  Label73.Active          = 1;
  Label73.Caption         = Label73_Caption;
  Label73.FontName        = Tahoma11x13_Regular;
  Label73.Font_Color      = 0x07FF;
  Label73.VerticalText    = 0;
  Label73.OnUpPtr         = 0;
  Label73.OnDownPtr       = 0;
  Label73.OnClickPtr      = 0;
  Label73.OnPressPtr      = 0;

  Label74.OwnerScreen     = &Screen1;
  Label74.Order           = 73;
  Label74.Left            = 453;
  Label74.Top             = 149;
  Label74.Width           = 20;
  Label74.Height          = 15;
  Label74.Visible         = 1;
  Label74.Active          = 1;
  Label74.Caption         = Label74_Caption;
  Label74.FontName        = Tahoma11x13_Regular;
  Label74.Font_Color      = 0x07FF;
  Label74.VerticalText    = 0;
  Label74.OnUpPtr         = 0;
  Label74.OnDownPtr       = 0;
  Label74.OnClickPtr      = 0;
  Label74.OnPressPtr      = 0;

  Label75.OwnerScreen     = &Screen1;
  Label75.Order           = 74;
  Label75.Left            = 441;
  Label75.Top             = 163;
  Label75.Width           = 32;
  Label75.Height          = 15;
  Label75.Visible         = 1;
  Label75.Active          = 1;
  Label75.Caption         = Label75_Caption;
  Label75.FontName        = Tahoma11x13_Regular;
  Label75.Font_Color      = 0x07FF;
  Label75.VerticalText    = 0;
  Label75.OnUpPtr         = 0;
  Label75.OnDownPtr       = 0;
  Label75.OnClickPtr      = 0;
  Label75.OnPressPtr      = 0;

  Label76.OwnerScreen     = &Screen1;
  Label76.Order           = 75;
  Label76.Left            = 441;
  Label76.Top             = 176;
  Label76.Width           = 30;
  Label76.Height          = 15;
  Label76.Visible         = 1;
  Label76.Active          = 1;
  Label76.Caption         = Label76_Caption;
  Label76.FontName        = Tahoma11x13_Regular;
  Label76.Font_Color      = 0x07FF;
  Label76.VerticalText    = 0;
  Label76.OnUpPtr         = 0;
  Label76.OnDownPtr       = 0;
  Label76.OnClickPtr      = 0;
  Label76.OnPressPtr      = 0;

  Label77.OwnerScreen     = &Screen1;
  Label77.Order           = 76;
  Label77.Left            = 398;
  Label77.Top             = 65;
  Label77.Width           = 42;
  Label77.Height          = 15;
  Label77.Visible         = 1;
  Label77.Active          = 1;
  Label77.Caption         = Label77_Caption;
  Label77.FontName        = Tahoma11x13_Regular;
  Label77.Font_Color      = 0xFFE0;
  Label77.VerticalText    = 0;
  Label77.OnUpPtr         = 0;
  Label77.OnDownPtr       = 0;
  Label77.OnClickPtr      = 0;
  Label77.OnPressPtr      = 0;

  Label78.OwnerScreen     = &Screen1;
  Label78.Order           = 77;
  Label78.Left            = 65;
  Label78.Top             = 702;
  Label78.Width           = 75;
  Label78.Height          = 15;
  Label78.Visible         = 1;
  Label78.Active          = 1;
  Label78.Caption         = Label78_Caption;
  Label78.FontName        = Tahoma11x13_Regular;
  Label78.Font_Color      = 0xFC17;
  Label78.VerticalText    = 0;
  Label78.OnUpPtr         = 0;
  Label78.OnDownPtr       = 0;
  Label78.OnClickPtr      = 0;
  Label78.OnPressPtr      = 0;

  Label79.OwnerScreen     = &Screen1;
  Label79.Order           = 78;
  Label79.Left            = 74;
  Label79.Top             = 717;
  Label79.Width           = 69;
  Label79.Height          = 15;
  Label79.Visible         = 1;
  Label79.Active          = 1;
  Label79.Caption         = Label79_Caption;
  Label79.FontName        = Tahoma11x13_Regular;
  Label79.Font_Color      = 0xFC17;
  Label79.VerticalText    = 0;
  Label79.OnUpPtr         = 0;
  Label79.OnDownPtr       = 0;
  Label79.OnClickPtr      = 0;
  Label79.OnPressPtr      = 0;

  Label80.OwnerScreen     = &Screen1;
  Label80.Order           = 79;
  Label80.Left            = 74;
  Label80.Top             = 728;
  Label80.Width           = 78;
  Label80.Height          = 15;
  Label80.Visible         = 1;
  Label80.Active          = 1;
  Label80.Caption         = Label80_Caption;
  Label80.FontName        = Tahoma11x13_Regular;
  Label80.Font_Color      = 0xFC17;
  Label80.VerticalText    = 0;
  Label80.OnUpPtr         = 0;
  Label80.OnDownPtr       = 0;
  Label80.OnClickPtr      = 0;
  Label80.OnPressPtr      = 0;

  Label81.OwnerScreen     = &Screen1;
  Label81.Order           = 80;
  Label81.Left            = 74;
  Label81.Top             = 741;
  Label81.Width           = 85;
  Label81.Height          = 15;
  Label81.Visible         = 1;
  Label81.Active          = 1;
  Label81.Caption         = Label81_Caption;
  Label81.FontName        = Tahoma11x13_Regular;
  Label81.Font_Color      = 0xFC17;
  Label81.VerticalText    = 0;
  Label81.OnUpPtr         = 0;
  Label81.OnDownPtr       = 0;
  Label81.OnClickPtr      = 0;
  Label81.OnPressPtr      = 0;

  Label82.OwnerScreen     = &Screen1;
  Label82.Order           = 81;
  Label82.Left            = 74;
  Label82.Top             = 753;
  Label82.Width           = 92;
  Label82.Height          = 15;
  Label82.Visible         = 1;
  Label82.Active          = 1;
  Label82.Caption         = Label82_Caption;
  Label82.FontName        = Tahoma11x13_Regular;
  Label82.Font_Color      = 0xFC17;
  Label82.VerticalText    = 0;
  Label82.OnUpPtr         = 0;
  Label82.OnDownPtr       = 0;
  Label82.OnClickPtr      = 0;
  Label82.OnPressPtr      = 0;

  Label83.OwnerScreen     = &Screen1;
  Label83.Order           = 82;
  Label83.Left            = 74;
  Label83.Top             = 764;
  Label83.Width           = 92;
  Label83.Height          = 15;
  Label83.Visible         = 1;
  Label83.Active          = 1;
  Label83.Caption         = Label83_Caption;
  Label83.FontName        = Tahoma11x13_Regular;
  Label83.Font_Color      = 0xFC17;
  Label83.VerticalText    = 0;
  Label83.OnUpPtr         = 0;
  Label83.OnDownPtr       = 0;
  Label83.OnClickPtr      = 0;
  Label83.OnPressPtr      = 0;

  Label84.OwnerScreen     = &Screen1;
  Label84.Order           = 83;
  Label84.Left            = 74;
  Label84.Top             = 776;
  Label84.Width           = 83;
  Label84.Height          = 15;
  Label84.Visible         = 1;
  Label84.Active          = 1;
  Label84.Caption         = Label84_Caption;
  Label84.FontName        = Tahoma11x13_Regular;
  Label84.Font_Color      = 0xFC17;
  Label84.VerticalText    = 0;
  Label84.OnUpPtr         = 0;
  Label84.OnDownPtr       = 0;
  Label84.OnClickPtr      = 0;
  Label84.OnPressPtr      = 0;

  Label85.OwnerScreen     = &Screen1;
  Label85.Order           = 84;
  Label85.Left            = 83;
  Label85.Top             = 681;
  Label85.Width           = 50;
  Label85.Height          = 15;
  Label85.Visible         = 1;
  Label85.Active          = 1;
  Label85.Caption         = Label85_Caption;
  Label85.FontName        = Tahoma11x13_Regular;
  Label85.Font_Color      = 0xFC17;
  Label85.VerticalText    = 0;
  Label85.OnUpPtr         = 0;
  Label85.OnDownPtr       = 0;
  Label85.OnClickPtr      = 0;
  Label85.OnPressPtr      = 0;

  Label86.OwnerScreen     = &Screen1;
  Label86.Order           = 85;
  Label86.Left            = 363;
  Label86.Top             = 144;
  Label86.Width           = 61;
  Label86.Height          = 15;
  Label86.Visible         = 1;
  Label86.Active          = 1;
  Label86.Caption         = Label86_Caption;
  Label86.FontName        = Tahoma11x13_Regular;
  Label86.Font_Color      = 0x07FF;
  Label86.VerticalText    = 0;
  Label86.OnUpPtr         = 0;
  Label86.OnDownPtr       = 0;
  Label86.OnClickPtr      = 0;
  Label86.OnPressPtr      = 0;

  Label87.OwnerScreen     = &Screen1;
  Label87.Order           = 86;
  Label87.Left            = 363;
  Label87.Top             = 167;
  Label87.Width           = 61;
  Label87.Height          = 15;
  Label87.Visible         = 1;
  Label87.Active          = 1;
  Label87.Caption         = Label87_Caption;
  Label87.FontName        = Tahoma11x13_Regular;
  Label87.Font_Color      = 0x07FF;
  Label87.VerticalText    = 0;
  Label87.OnUpPtr         = 0;
  Label87.OnDownPtr       = 0;
  Label87.OnClickPtr      = 0;
  Label87.OnPressPtr      = 0;

  Label88.OwnerScreen     = &Screen1;
  Label88.Order           = 87;
  Label88.Left            = 150;
  Label88.Top             = 12;
  Label88.Width           = 60;
  Label88.Height          = 15;
  Label88.Visible         = 1;
  Label88.Active          = 1;
  Label88.Caption         = Label88_Caption;
  Label88.FontName        = Tahoma11x13_Regular;
  Label88.Font_Color      = 0x07FF;
  Label88.VerticalText    = 0;
  Label88.OnUpPtr         = 0;
  Label88.OnDownPtr       = 0;
  Label88.OnClickPtr      = 0;
  Label88.OnPressPtr      = 0;

  Label89.OwnerScreen     = &Screen1;
  Label89.Order           = 88;
  Label89.Left            = 150;
  Label89.Top             = 26;
  Label89.Width           = 61;
  Label89.Height          = 15;
  Label89.Visible         = 1;
  Label89.Active          = 1;
  Label89.Caption         = Label89_Caption;
  Label89.FontName        = Tahoma11x13_Regular;
  Label89.Font_Color      = 0x07FF;
  Label89.VerticalText    = 0;
  Label89.OnUpPtr         = 0;
  Label89.OnDownPtr       = 0;
  Label89.OnClickPtr      = 0;
  Label89.OnPressPtr      = 0;

  Label90.OwnerScreen     = &Screen1;
  Label90.Order           = 89;
  Label90.Left            = 150;
  Label90.Top             = 41;
  Label90.Width           = 85;
  Label90.Height          = 15;
  Label90.Visible         = 1;
  Label90.Active          = 1;
  Label90.Caption         = Label90_Caption;
  Label90.FontName        = Tahoma11x13_Regular;
  Label90.Font_Color      = 0x07FF;
  Label90.VerticalText    = 0;
  Label90.OnUpPtr         = 0;
  Label90.OnDownPtr       = 0;
  Label90.OnClickPtr      = 0;
  Label90.OnPressPtr      = 0;

  Label91.OwnerScreen     = &Screen1;
  Label91.Order           = 90;
  Label91.Left            = 250;
  Label91.Top             = 287;
  Label91.Width           = 100;
  Label91.Height          = 15;
  Label91.Visible         = 1;
  Label91.Active          = 1;
  Label91.Caption         = Label91_Caption;
  Label91.FontName        = Tahoma11x13_Regular;
  Label91.Font_Color      = 0xFFE0;
  Label91.VerticalText    = 0;
  Label91.OnUpPtr         = 0;
  Label91.OnDownPtr       = 0;
  Label91.OnClickPtr      = 0;
  Label91.OnPressPtr      = 0;

  Label92.OwnerScreen     = &Screen1;
  Label92.Order           = 91;
  Label92.Left            = 150;
  Label92.Top             = 308;
  Label92.Width           = 78;
  Label92.Height          = 15;
  Label92.Visible         = 1;
  Label92.Active          = 1;
  Label92.Caption         = Label92_Caption;
  Label92.FontName        = Tahoma11x13_Regular;
  Label92.Font_Color      = 0x07FF;
  Label92.VerticalText    = 0;
  Label92.OnUpPtr         = 0;
  Label92.OnDownPtr       = 0;
  Label92.OnClickPtr      = 0;
  Label92.OnPressPtr      = 0;

  Label93.OwnerScreen     = &Screen1;
  Label93.Order           = 92;
  Label93.Left            = 150;
  Label93.Top             = 328;
  Label93.Width           = 65;
  Label93.Height          = 15;
  Label93.Visible         = 1;
  Label93.Active          = 1;
  Label93.Caption         = Label93_Caption;
  Label93.FontName        = Tahoma11x13_Regular;
  Label93.Font_Color      = 0x07FF;
  Label93.VerticalText    = 0;
  Label93.OnUpPtr         = 0;
  Label93.OnDownPtr       = 0;
  Label93.OnClickPtr      = 0;
  Label93.OnPressPtr      = 0;

  Label94.OwnerScreen     = &Screen1;
  Label94.Order           = 93;
  Label94.Left            = 150;
  Label94.Top             = 341;
  Label94.Width           = 67;
  Label94.Height          = 15;
  Label94.Visible         = 1;
  Label94.Active          = 1;
  Label94.Caption         = Label94_Caption;
  Label94.FontName        = Tahoma11x13_Regular;
  Label94.Font_Color      = 0x07FF;
  Label94.VerticalText    = 0;
  Label94.OnUpPtr         = 0;
  Label94.OnDownPtr       = 0;
  Label94.OnClickPtr      = 0;
  Label94.OnPressPtr      = 0;

  Label95.OwnerScreen     = &Screen1;
  Label95.Order           = 94;
  Label95.Left            = 150;
  Label95.Top             = 354;
  Label95.Width           = 73;
  Label95.Height          = 15;
  Label95.Visible         = 1;
  Label95.Active          = 1;
  Label95.Caption         = Label95_Caption;
  Label95.FontName        = Tahoma11x13_Regular;
  Label95.Font_Color      = 0x07FF;
  Label95.VerticalText    = 0;
  Label95.OnUpPtr         = 0;
  Label95.OnDownPtr       = 0;
  Label95.OnClickPtr      = 0;
  Label95.OnPressPtr      = 0;

  Label96.OwnerScreen     = &Screen1;
  Label96.Order           = 95;
  Label96.Left            = 250;
  Label96.Top             = 307;
  Label96.Width           = 92;
  Label96.Height          = 15;
  Label96.Visible         = 1;
  Label96.Active          = 1;
  Label96.Caption         = Label96_Caption;
  Label96.FontName        = Tahoma11x13_Regular;
  Label96.Font_Color      = 0xFFE0;
  Label96.VerticalText    = 0;
  Label96.OnUpPtr         = 0;
  Label96.OnDownPtr       = 0;
  Label96.OnClickPtr      = 0;
  Label96.OnPressPtr      = 0;

  Label97.OwnerScreen     = &Screen1;
  Label97.Order           = 96;
  Label97.Left            = 250;
  Label97.Top             = 318;
  Label97.Width           = 92;
  Label97.Height          = 15;
  Label97.Visible         = 1;
  Label97.Active          = 1;
  Label97.Caption         = Label97_Caption;
  Label97.FontName        = Tahoma11x13_Regular;
  Label97.Font_Color      = 0xFFE0;
  Label97.VerticalText    = 0;
  Label97.OnUpPtr         = 0;
  Label97.OnDownPtr       = 0;
  Label97.OnClickPtr      = 0;
  Label97.OnPressPtr      = 0;

  Label98.OwnerScreen     = &Screen1;
  Label98.Order           = 97;
  Label98.Left            = 250;
  Label98.Top             = 344;
  Label98.Width           = 92;
  Label98.Height          = 15;
  Label98.Visible         = 1;
  Label98.Active          = 1;
  Label98.Caption         = Label98_Caption;
  Label98.FontName        = Tahoma11x13_Regular;
  Label98.Font_Color      = 0xFFE0;
  Label98.VerticalText    = 0;
  Label98.OnUpPtr         = 0;
  Label98.OnDownPtr       = 0;
  Label98.OnClickPtr      = 0;
  Label98.OnPressPtr      = 0;

  Label99.OwnerScreen     = &Screen1;
  Label99.Order           = 98;
  Label99.Left            = 250;
  Label99.Top             = 331;
  Label99.Width           = 92;
  Label99.Height          = 15;
  Label99.Visible         = 1;
  Label99.Active          = 1;
  Label99.Caption         = Label99_Caption;
  Label99.FontName        = Tahoma11x13_Regular;
  Label99.Font_Color      = 0xFFE0;
  Label99.VerticalText    = 0;
  Label99.OnUpPtr         = 0;
  Label99.OnDownPtr       = 0;
  Label99.OnClickPtr      = 0;
  Label99.OnPressPtr      = 0;

  Label100.OwnerScreen     = &Screen1;
  Label100.Order           = 99;
  Label100.Left            = 5;
  Label100.Top             = 750;
  Label100.Width           = 60;
  Label100.Height          = 15;
  Label100.Visible         = 1;
  Label100.Active          = 1;
  Label100.Caption         = Label100_Caption;
  Label100.FontName        = Tahoma11x13_Regular;
  Label100.Font_Color      = 0xF800;
  Label100.VerticalText    = 0;
  Label100.OnUpPtr         = 0;
  Label100.OnDownPtr       = 0;
  Label100.OnClickPtr      = 0;
  Label100.OnPressPtr      = 0;
}

static char IsInsideObject (unsigned int X, unsigned int Y, unsigned int Left, unsigned int Top, unsigned int Width, unsigned int Height) { // static
  if ( (Left<= X) && (Left+ Width - 1 >= X) &&
       (Top <= Y)  && (Top + Height - 1 >= Y) )
    return 1;
  else
    return 0;
}


#define GetLabel(index)               CurrentScreen->Labels[index]


void DrawLabel(TLabel *ALabel) {
  if (ALabel->Visible != 0) {
    if (ALabel->VerticalText != 0)
      TFT_Set_Font(ALabel->FontName, ALabel->Font_Color, FO_VERTICAL_COLUMN);
    else
      TFT_Set_Font(ALabel->FontName, ALabel->Font_Color, FO_HORIZONTAL);
    TFT_Write_Text(ALabel->Caption, ALabel->Left, ALabel->Top);
  }
}

void DrawScreen(TScreen *aScreen) {
 unsigned int order;
  unsigned short label_idx;
  TLabel *local_label;
  char save_bled, save_bled_direction;

  object_pressed = 0;
  order = 0;
  label_idx = 0;
  CurrentScreen = aScreen;

  if ((display_width != CurrentScreen->Width) || (display_height != CurrentScreen->Height)) {
    save_bled = TFT_BLED;
    TFT_BLED           = 0;
    TFT_Set_Active(Set_Index, Write_Command, Write_Data);
    TFT_Init_SSD1963_7Inch_800x480(CurrentScreen->Width, CurrentScreen->Height);
    STMPE610_SetSize(CurrentScreen->Width, CurrentScreen->Height);
    TFT_Fill_Screen(CurrentScreen->Color);
    TFT_Set_DBC_SSD1963(255);
    display_width = CurrentScreen->Width;
    display_height = CurrentScreen->Height;
    TFT_BLED           = save_bled;
  }
  else
    TFT_Fill_Screen(CurrentScreen->Color);


  while (order < CurrentScreen->ObjectsCount) {
    if (label_idx < CurrentScreen->LabelsCount) {
      local_label = GetLabel(label_idx);
      if (order == local_label->Order) {
        label_idx++;
        order++;
        DrawLabel(local_label);
      }
    }

  }
}

void Get_Object(unsigned int X, unsigned int Y) {
  label_order         = -1;
  //  Labels
  for ( _object_count = 0 ; _object_count < CurrentScreen->LabelsCount ; _object_count++ ) {
    local_label = GetLabel(_object_count);
    if (local_label->Active != 0) {
      if (IsInsideObject(X, Y, local_label->Left, local_label->Top,
                         local_label->Width, local_label->Height) == 1) {
        label_order = local_label->Order;
        exec_label = local_label;
      }
    }
  }

  _object_count = -1;
  if (label_order >  _object_count )
    _object_count = label_order;
}


void Process_TP_Press(unsigned int X, unsigned int Y) {
  exec_label          = 0;

  Get_Object(X, Y);

  if (_object_count != -1) {
    if (_object_count == label_order) {
      if (exec_label->Active != 0) {
        if (exec_label->OnPressPtr != 0) {
          exec_label->OnPressPtr();
          return;
        }
      }
    }

  }
}

void Process_TP_Up(unsigned int X, unsigned int Y) {

  exec_label          = 0;

  Get_Object(X, Y);


  if (_object_count != -1) {
  // Labels
    if (_object_count == label_order) {
      if (exec_label->Active != 0) {
        if (exec_label->OnUpPtr != 0)
          exec_label->OnUpPtr();
        if (PressedObject == (void *)exec_label)
          if (exec_label->OnClickPtr != 0)
            exec_label->OnClickPtr();
        PressedObject = 0;
        PressedObjectType = -1;
        return;
      }
    }

  }
  PressedObject = 0;
  PressedObjectType = -1;
}

void Process_TP_Down(unsigned int X, unsigned int Y) {

  object_pressed      = 0;
  exec_label          = 0;

  Get_Object(X, Y);

  if (_object_count != -1) {
    if (_object_count == label_order) {
      if (exec_label->Active != 0) {
        PressedObject = (void *)exec_label;
        PressedObjectType = 2;
        if (exec_label->OnDownPtr != 0) {
          exec_label->OnDownPtr();
          return;
        }
      }
    }

  }
}

void Check_TP() {
  if (STMPE610_PressDetect()) {
    if (STMPE610_GetLastCoordinates(&Xcoord, &Ycoord) == 0) {
    // After a PRESS is detected read X-Y and convert it to Display dimensions space
      Process_TP_Press(Xcoord, Ycoord);
      if (PenDown == 0) {
        PenDown = 1;
        Process_TP_Down(Xcoord, Ycoord);
      }
    }
  }
  else if (PenDown == 1) {
    PenDown = 0;
    Process_TP_Up(Xcoord, Ycoord);
  }
}

void Init_MCU() {
  // Place your code here

  // If bus is busy wait SDA high before initializing I2C module
  GPIO_Digital_Output(&GPIOB_BASE, _GPIO_PINMASK_6);
  GPIO_Digital_Input(&GPIOB_BASE, _GPIO_PINMASK_7);
  GPIOB_ODR.B6 = 1;
  while (GPIOB_IDR.B7 == 0) {
    GPIOB_ODR.B6 = 0;
    Delay_us(10);
    GPIOB_ODR.B6 = 1;
    Delay_us(10);
  }
  I2C1_Init_Advanced(400000, &_GPIO_MODULE_I2C1_PB67);

  TFT_Set_Default_Mode();
  GPIO_Digital_Output(&GPIOG_BASE, 0x00FF);
  GPIO_Digital_Output(&GPIOE_BASE, 0xFF00);
  GPIO_Digital_Output(&GPIOB_BASE, _GPIO_PINMASK_4);
  GPIOB_ODR.B4 = 0;
  TFT_Set_Default_Mode();
  TFT_Set_MM_Plus();
  STMPE610_SetDefaultMode();
}

char STMPE610_Config()  {
  STMPE610_SetI2CAddress(STMPE610_I2C_ADDR1);
  if (STMPE610_IsOperational() != 0){
    return STMPE610_IO_NOT_OPERATIONAL;
  }

  STMPE610_Reset();
  STMPE610_Module(STMPE610_MODULE_TS | STMPE610_MODULE_ADC, STMPE610_ENABLE);
  STMPE610_AlternateFunction(STMPE610_GPIO_PIN1, STMPE610_ENABLE);
  STMPE610_SetGPIOPin(STMPE610_GPIO_PIN1, 0);   // IN1 to "0" -> I2C communication
  STMPE610_SetSize(480,800);
  STMPE610_Module(STMPE610_MODULE_TS | STMPE610_MODULE_ADC, STMPE610_ENABLE);
  STMPE610_EnableInterrupt(STMPE610_IE_TOUCH_DET | STMPE610_IE_FIFO_TH | STMPE610_IE_FIFO_0FLOW, STMPE610_ENABLE);
  STMPE610_ConfigureInterrupt(STMPE610_INT_POLARITY_ACTIVE_HIGH | STMPE610_INT_TYPE_EDGE | STMPE610_INT_ENABLE_ALL);
  STMPE610_SetADC(STMPE610_ADC_CTRL1_SAMPLETIME_44 | STMPE610_ADC_CTRL1_ADC_12BIT | STMPE610_ADC_CTRL1_INT_REFERENCE);
  Delay_10ms(); Delay_10ms();
  STMPE610_SetADCClock(STMPE610_ADC_CTRL2_3250_kHZ);
  STMPE610_AlternateFunction(STMPE610_GPIO_PIN4 | STMPE610_GPIO_PIN5 | STMPE610_GPIO_PIN6 | STMPE610_GPIO_PIN7, STMPE610_DISABLE);
  STMPE610_ConfigureTSC(STMPE610_TSC_CFG_AVE_CTRL_4S, STMPE610_TSC_CFG_TOUCH_DET_DELAY_500uS, STMPE610_TSC_CFG_TOUCH_SETTLING_500uS);
  STMPE610_SetFIFOThreshold(1);
  STMPE610_ResetFIFO();
  STMPE610_TSIDrive(STMPE610_TSC_I_DRIVE_20mA);
  STMPE610_TSControl(STMPE610_TSC_CTRL_TRACK0 | STMPE610_TSC_CTRL_ACQU_XYZ | STMPE610_TSC_CTRL_ENABLE);
  STMPE610_ZDataFraction(STMPE610_FRACP4_WHOLP4);
  STMPE610_SetTouchPressureThreshold(70);
  STMPE610_ClearInterrupts();
  STMPE610_WriteReg(STMPE610_INT_CTRL_REG, 0x01);
  return STMPE610_OK;
}


void Start_TP() {
TTPConstants TPConstsStruct;
  Init_MCU();

  InitializeTouchPanel();
  if (STMPE610_Config() == STMPE610_OK) {
  } else {
    while(1);
  }


  // You can get calibration constants using touch panel calibration example
  TPConstsStruct.X_Min = 105;
  TPConstsStruct.X_Max = 3925;
  TPConstsStruct.Y_Min = 250;
  TPConstsStruct.Y_Max = 3820;
  TPConstsStruct.Rotate = 3;
  STMPE610_SetCalibrationConsts(&TPConstsStruct);

  InitializeObjects();
  display_width = Screen1.Width;
  display_height = Screen1.Height;
  DrawScreen(&Screen1);
}
